void checkSwitches()
{
  static byte previousstate[40];
  static byte currentstate[40];
  static long lasttime;
  byte index;


  if (millis() < lasttime) {
    // we wrapped around, lets just try again
    lasttime = millis();
  }


  if ((lasttime + DEBOUNCE) > millis()) {
    // not enough time has passed to debounce
    return; 
  }
  // ok we have waited DEBOUNCE milliseconds, lets reset the timer
  lasttime = millis();


  //BUTTONS
  //Collect button data from the 4901s
  //Pulse the latch pin:
  //set it to 1 to collect parallel data
  digitalWrite(BUTTONlatchPin,1);
  //set it to 1 to collect parallel data, wait
  delayMicroseconds(20);
  //set it to 0 to transmit data serially  
  digitalWrite(BUTTONlatchPin,0);

  //while the shift register is in serial mode
  //collect each shift register into a byte
  //the register attached to the chip comes in first
  for (byte i = 0; i < 5; i++) 
    BUTTONvar[i] = shiftIn(BUTTONdataPin, BUTTONclockPin);


  //write the button states to the currentstate array
  for (int i = 0; i < 40; i++)
    buttons[i] = BUTTONvar[i / 8] & (1 << (i % 8));

  for (index = 0; index < 40; index++) {
    justpressed[index] = 0;       // when we start, we clear out the "just" indicators
    justreleased[index] = 0;

    currentstate[index] = (buttons[index] == 0) ? HIGH : LOW;

    if (currentstate[index] == previousstate[index]) {
      if ((pressed[index] == LOW) && (currentstate[index] == LOW)) {
        // just pressed
        justpressed[index] = 1;
      }
      else if ((pressed[index] == HIGH) && (currentstate[index] == HIGH)) {
        // just released
        justreleased[index] = 1;
      }
      pressed[index] = !currentstate[index];  // remember, digital HIGH means NOT pressed
    }
    previousstate[index] = currentstate[index];   // keep a running tally of the buttons
  }
}

byte shiftIn(int myDataPin, int myClockPin) { 
  int i;
  int temp = 0;
  int pinState;
  byte myDataIn = 0;

  pinMode(myClockPin, OUTPUT);
  pinMode(myDataPin, INPUT);

  for (i=0; i<=7; i++)
  {
    digitalWrite(myClockPin, 0);
    delayMicroseconds(2);
    temp = digitalRead(myDataPin);
    if (temp) {
      pinState = 1;
      //set the bit to 0 no matter what
      myDataIn = myDataIn | (1 << i);
    }
    else {
      pinState = 0;
    }
    digitalWrite(myClockPin, 1);
  }
  return myDataIn;
}

void buttonHandler()
{
  switch (mode)
  {
  case 0: // EDIT MODE
    for (byte i = 0; i < 40; i++)
    {
      if (pressed[32] && justpressed[39])
      {
        clearAll();
        clearJust();
        shiftL = true;
      }

      if (justreleased[32])
      {
        if (!shiftL)
          mode = 2;
        else
          shiftL = false;
        clearJust();
      }

      if (justreleased[39])
      {
        lockPot(6);
        clearJust();
      }

      if (justpressed[i])
      {
        switch(i)
        {
        case 33:
          if (currentVoice != 0)
            currentVoice = 0; // kick
          else 
          {
            if (seqRunning)
            {
              seqRunning = false;
              midiA.sendRealTime(midi::Stop); // send a midi clock stop signal
              tickCounter = 0;
              currentStep = 0;
            }
            else
            {
              seqRunning = true;
              midiA.sendRealTime(midi::Start); // send a midi clock start signal
            }
          }
          break;
        case 34:
          currentVoice = 1; // snare
          break;
        case 35:
          currentVoice = 2; // hat
          break;
        case 36:
          currentVoice = 3; // crash
          break;
        case 37:
          bpm--;
          bpmChange();
          break;
        case 38:
          bpm++;
          bpmChange();
          break;
        }

        switch(currentVoice)
        {
        case 0:
          if (i < 32)
            kick[i / 8] = kick[i / 8] ^ (1 << (7 - (i % 8)));
          break;
        case 1:
          if (i < 32)
            snare[i / 8] = snare[i / 8] ^ (1 << (7 - (i % 8)));
          break;
        case 2:
          if (i < 32)
            hat[i / 8] = hat[i / 8] ^ (1 << (7 - (i % 8)));
          break;
        case 3:
          if (i < 32)
            crash[i / 8] = crash[i / 8] ^ (1 << (7 - (i % 8)));
          break;
        }
        clearJust();
      }
    }
    break;

  case 2: // TRIGGER MODE

    if (pressed[32])
    {
      for (byte i = 0; i < 32; i++)
      {
        if (justpressed[i])
        {
          if (checkToc(i + (trigPage * 32)))
          {
            confirm = i + (trigPage * 32);
            fastBlink = roughMillis;
            save = false;
          }
          shiftL = true;
          clearJust();
        }
      }
      for (byte i = 0; i < 2; i++)
      {
        if (justpressed[33 + i])
        {
          trigPage = i;
          shiftL = true;
          clearJust();
        }
      }
    }

    else if (pressed[33])
      repeat = true;

    else if (justreleased[33])
    {
      repeat = false;
      currentStep = trueStep;
      clearJust();
    }

    for (byte i = 0; i < 4; i++)
    {
      if (justpressed[35 + i])
        voiceActive[i] = !voiceActive[i]; // toggle the voice on and off
    }

    for (byte i = 0; i < 32; i++)
    {
      if (justpressed[i])
      {
        if ((i + (trigPage * 32)) ==  confirm)
        {
          if (save == true)
          {
            tocWrite(patchNum);
            delay(1000);
            savePatch(patchNum);
            delay(1000);
          }
          else
            tocClear(i + (trigPage * 32));

          confirm = 255;
          save = false;
        }
        else
        {
          save = false;
          confirm = 255;
          longPress = roughMillis;
        }
        clearJust();
      }

      if (pressed[i])
      {
        if (longPress != 0 && (roughMillis - longPress) > 300)
        {
          patchNum = i + (trigPage * 32);
          longPress = 0;
          if (patchNum < 56)
          {
            if (!checkToc(patchNum))
            {   
              tocWrite(patchNum);
              delay(1000);
              savePatch(patchNum);
              delay(1000);
            }
            else
            {
              confirm = patchNum;
              save = true;
            }
          }
        }
      }

      if (justreleased[i])
      {
        if (longPress != 0)
        {
          patchNum = i + (trigPage * 32);
          longPress = 0;
          if (checkToc(patchNum))
          {
            cued = patchNum;
            if(triggerChannel != 0)
              midiA.sendNoteOn(cued + 64, 127, triggerChannel); // send a trigger message
          }
        }
        longPress = 0;
        clearJust();
      }
    }

    if (justreleased[32])
    {
      if (!shiftL)
        mode = 0;
      else
        shiftL = false;
      clearJust();
    }
    break;

  case 3: // LIVE MODE
    for (byte i = 0; i < 40; i++)
    {
      if (justpressed[i])
      {
        if (i % 4 == 0)
        {
          // kick
          index4=0;
          accumulator4=0;
          B4_latch=1;
        }
        else if(i % 4 == 1)
        {
          // snare
          index3=0;
          accumulator3=0;
          B3_latch=1; 
        }
        else if(i % 4 == 2)
        {
          hatPitch = i * 6;  // to get a rough range from 0 - 255 
          // hat
          index=0;
          accumulator=0;
          B1_latch=1;
        }
        else if(i % 4 == 3)
        {
          crashPitch = i * 6;  // to get a rough range from 0 - 255 
          // crash
          index2=0;
          accumulator2=0;
          B2_latch=1;
        }
        clearJust();
      }
    }
    break;
  }

}


void clearAll()
{
  for (byte i = 0; i < 4; i++)
  {
    kick[i] = 0;
    snare[i] = 0;
    hat[i] = 0;
    crash[i] = 0;
  }
  //autoOn = false;
  resetAuto();
}

void resetAuto()
{
  for (byte i = 0; i < 32; i++)
  {
    hatAuto[i] = 128;
    crashAuto[i] = 128;
  }
}

void clearJust()
{
  for (byte i = 0; i < 40; i++) 
  {
    justpressed[i] = 0; 
    justreleased[i] = 0;
  }
}





















































