 /*********************************************************************************************
 ***   GROOVESIZER BRAVO v.26 - 4 Voice Drum Machine and 32-Step Sequencer
 ***   for the GROOVESIZER MB http://groovesizer.com
 ***   June 2014
 ***   by MoShang (Jean Marais) - moshang@groovesizer.com
 ***   Synth engine based on by The Bleep Drum v09 http://bleeplabs.com/store/bleep-drum-midi/ 
 ***   by Dr. Bleep (John-Mike Reed) drbleep@bleeplabs.com
 ***   Licensed under a Creative Commons Attribution-ShareAlike 3.0
 *********************************************************************************************/

int versionNumber = 26;

#include <MIDI.h> 
#include <avr/pgmspace.h>
#include <SPI.h>
#include <TimerOne.h>
#include <Wire.h>               // I2C library (required by the EEPROM library below)
#include <EEPROM24LC256_512.h>  // https://github.com/mikeneiderhauser/I2C-EEPROM-Arduino

EEPROM256_512 mem_1;            // define the eeprom chip

const char noise_table[] PROGMEM = {
};

const char kick_table[] PROGMEM = 
{
  129
    ,122
    ,135
    ,230
    ,250
    ,245
    ,245
    ,243
    ,243
    ,239
    ,239
    ,237
    ,236
    ,234
    ,233
    ,232
    ,226
    ,204
    ,184
    ,164
    ,147
    ,129
    ,115
    ,101
    ,90
    ,81
    ,74
    ,70
    ,66
    ,65
    ,65
    ,67
    ,70
    ,75
    ,80
    ,85
    ,92
    ,98
    ,105
    ,112
    ,117
    ,122
    ,127
    ,131
    ,133
    ,135
    ,137
    ,137
    ,135
    ,134
    ,130
    ,126
    ,121
    ,115
    ,110
    ,102
    ,94
    ,86
    ,78
    ,69
    ,61
    ,52
    ,43
    ,35
    ,28
    ,21
    ,14
    ,9
    ,8
    ,10
    ,11
    ,13
    ,14
    ,16
    ,17
    ,18
    ,19
    ,21
    ,23
    ,24
    ,24
    ,27
    ,35
    ,43
    ,53
    ,63
    ,73
    ,84
    ,96
    ,108
    ,120
    ,133
    ,146
    ,158
    ,171
    ,182
    ,195
    ,207
    ,219
    ,230
    ,240
    ,248
    ,245
    ,244
    ,243
    ,242
    ,240
    ,239
    ,238
    ,237
    ,236
    ,234
    ,233
    ,232
    ,231
    ,230
    ,228
    ,228
    ,226
    ,225
    ,224
    ,223
    ,222
    ,221
    ,219
    ,218
    ,217
    ,216
    ,215
    ,214
    ,211
    ,202
    ,191
    ,180
    ,168
    ,157
    ,146
    ,135
    ,123
    ,112
    ,101
    ,90
    ,79
    ,68
    ,57
    ,47
    ,37
    ,28
    ,19
    ,12
    ,13
    ,13
    ,14
    ,16
    ,17
    ,18
    ,19
    ,20
    ,21
    ,22
    ,24
    ,24
    ,25
    ,26
    ,28
    ,29
    ,30
    ,31
    ,32
    ,33
    ,34
    ,35
    ,36
    ,37
    ,38
    ,39
    ,40
    ,41
    ,42
    ,43
    ,44
    ,45
    ,45
    ,46
    ,48
    ,48
    ,49
    ,52
    ,59
    ,69
    ,77
    ,86
    ,95
    ,103
    ,112
    ,121
    ,130
    ,138
    ,147
    ,155
    ,162
    ,171
    ,180
    ,186
    ,194
    ,202
    ,209
    ,215
    ,223
    ,229
    ,234
    ,237
    ,237
    ,236
    ,235
    ,234
    ,233
    ,232
    ,231
    ,230
    ,229
    ,228
    ,227
    ,226
    ,226
    ,225
    ,223
    ,222
    ,221
    ,220
    ,220
    ,219
    ,218
    ,217
    ,216
    ,215
    ,214
    ,213
    ,213
    ,212
    ,211
    ,210
    ,209
    ,208
    ,207
    ,207
    ,206
    ,205
    ,204
    ,203
    ,202
    ,201
    ,201
    ,199
    ,199
    ,196
    ,191
    ,185
    ,180
    ,175
    ,169
    ,164
    ,158
    ,153
    ,147
    ,142
    ,137
    ,132
    ,126
    ,122
    ,116
    ,112
    ,107
    ,103
    ,99
    ,94
    ,90
    ,87
    ,83
    ,80
    ,77
    ,73
    ,71
    ,68
    ,65
    ,63
    ,61
    ,59
    ,57
    ,55
    ,54
    ,53
    ,52
    ,51
    ,50
    ,50
    ,50
    ,50
    ,50
    ,50
    ,50
    ,52
    ,52
    ,53
    ,54
    ,56
    ,57
    ,59
    ,60
    ,62
    ,64
    ,66
    ,68
    ,70
    ,72
    ,75
    ,78
    ,80
    ,83
    ,85
    ,88
    ,91
    ,93
    ,97
    ,100
    ,102
    ,105
    ,108
    ,111
    ,114
    ,116
    ,119
    ,122
    ,124
    ,128
    ,129
    ,132
    ,134
    ,137
    ,139
    ,141
    ,143
    ,145
    ,147
    ,149
    ,150
    ,152
    ,153
    ,155
    ,156
    ,156
    ,158
    ,158
    ,159
    ,160
    ,160
    ,160
    ,160
    ,160
    ,160
    ,160
    ,159
    ,159
    ,158
    ,157
    ,156
    ,156
    ,154
    ,153
    ,152
    ,150
    ,149
    ,147
    ,145
    ,143
    ,141
    ,139
    ,137
    ,134
    ,132
    ,130
    ,127
    ,125
    ,122
    ,120
    ,117
    ,114
    ,111
    ,109
    ,106
    ,103
    ,100
    ,97
    ,95
    ,92
    ,89
    ,86
    ,83
    ,81
    ,78
    ,76
    ,73
    ,70
    ,68
    ,65
    ,63
    ,61
    ,59
    ,57
    ,54
    ,53
    ,51
    ,49
    ,47
    ,46
    ,45
    ,44
    ,43
    ,43
    ,43
    ,44
    ,45
    ,46
    ,47
    ,48
    ,49
    ,49
    ,50
    ,51
    ,52
    ,52
    ,54
    ,54
    ,55
    ,56
    ,57
    ,58
    ,59
    ,59
    ,60
    ,61
    ,61
    ,63
    ,64
    ,65
    ,67
    ,68
    ,69
    ,71
    ,73
    ,75
    ,77
    ,79
    ,81
    ,83
    ,86
    ,88
    ,90
    ,93
    ,96
    ,99
    ,101
    ,104
    ,107
    ,110
    ,113
    ,117
    ,120
    ,123
    ,126
    ,130
    ,133
    ,136
    ,139
    ,142
    ,146
    ,150
    ,153
    ,155
    ,159
    ,163
    ,166
    ,169
    ,172
    ,175
    ,178
    ,181
    ,184
    ,187
    ,190
    ,193
    ,196
    ,198
    ,201
    ,203
    ,205
    ,207
    ,210
    ,212
    ,214
    ,216
    ,218
    ,220
    ,221
    ,223
    ,224
    ,225
    ,226
    ,227
    ,228
    ,229
    ,230
    ,231
    ,231
    ,232
    ,232
    ,232
    ,232
    ,231
    ,231
    ,231
    ,231
    ,230
    ,229
    ,229
    ,227
    ,227
    ,225
    ,225
    ,222
    ,221
    ,220
    ,218
    ,216
    ,215
    ,213
    ,210
    ,208
    ,206
    ,204
    ,201
    ,199
    ,196
    ,193
    ,191
    ,189
    ,186
    ,183
    ,180
    ,177
    ,174
    ,171
    ,168
    ,165
    ,162
    ,158
    ,155
    ,152
    ,150
    ,146
    ,142
    ,139
    ,137
    ,133
    ,130
    ,127
    ,124
    ,121
    ,118
    ,114
    ,111
    ,108
    ,105
    ,102
    ,99
    ,96
    ,94
    ,91
    ,88
    ,86
    ,83
    ,81
    ,78
    ,76
    ,74
    ,71
    ,69
    ,67
    ,65
    ,63
    ,61
    ,59
    ,58
    ,56
    ,55
    ,54
    ,52
    ,51
    ,50
    ,49
    ,48
    ,47
    ,47
    ,46
    ,46
    ,46
    ,46
    ,46
    ,46
    ,46
    ,46
    ,46
    ,47
    ,48
    ,48
    ,48
    ,49
    ,50
    ,51
    ,53
    ,54
    ,55
    ,56
    ,58
    ,59
    ,61
    ,62
    ,64
    ,66
    ,68
    ,70
    ,72
    ,74
    ,77
    ,79
    ,81
    ,83
    ,86
    ,87
    ,90
    ,93
    ,96
    ,98
    ,101
    ,103
    ,106
    ,109
    ,111
    ,114
    ,117
    ,120
    ,123
    ,125
    ,129
    ,132
    ,134
    ,137
    ,140
    ,142
    ,145
    ,148
    ,151
    ,154
    ,156
    ,159
    ,162
    ,165
    ,167
    ,169
    ,172
    ,175
    ,177
    ,180
    ,182
    ,184
    ,186
    ,188
    ,190
    ,192
    ,195
    ,197
    ,198
    ,200
    ,201
    ,204
    ,205
    ,206
    ,208
    ,209
    ,210
    ,211
    ,212
    ,214
    ,214
    ,215
    ,216
    ,216
    ,217
    ,217
    ,217
    ,218
    ,218
    ,218
    ,218
    ,218
    ,218
    ,217
    ,217
    ,217
    ,217
    ,215
    ,215
    ,214
    ,213
    ,213
    ,211
    ,211
    ,209
    ,208
    ,207
    ,205
    ,204
    ,202
    ,201
    ,199
    ,197
    ,195
    ,193
    ,191
    ,189
    ,187
    ,185
    ,183
    ,181
    ,179
    ,177
    ,174
    ,171
    ,169
    ,166
    ,164
    ,162
    ,159
    ,157
    ,154
    ,151
    ,149
    ,146
    ,144
    ,141
    ,138
    ,136
    ,132
    ,130
    ,127
    ,124
    ,122
    ,119
    ,117
    ,113
    ,111
    ,108
    ,106
    ,103
    ,100
    ,98
    ,96
    ,93
    ,90
    ,88
    ,86
    ,83
    ,81
    ,78
    ,77
    ,74
    ,72
    ,69
    ,68
    ,65
    ,64
    ,62
    ,60
    ,58
    ,57
    ,55
    ,53
    ,52
    ,50
    ,49
    ,48
    ,46
    ,46
    ,44
    ,43
    ,42
    ,42
    ,40
    ,40
    ,39
    ,38
    ,38
    ,37
    ,37
    ,37
    ,37
    ,36
    ,37
    ,36
    ,37
    ,37
    ,38
    ,38
    ,38
    ,39
    ,39
    ,40
    ,41
    ,42
    ,42
    ,43
    ,44
    ,46
    ,47
    ,48
    ,49
    ,50
    ,52
    ,53
    ,55
    ,57
    ,58
    ,60
    ,61
    ,63
    ,65
    ,67
    ,69
    ,71
    ,72
    ,75
    ,77
    ,79
    ,81
    ,84
    ,86
    ,88
    ,90
    ,93
    ,95
    ,97
    ,100
    ,102
    ,105
    ,107
    ,109
    ,112
    ,114
    ,117
    ,119
    ,121
    ,124
    ,127
    ,129
    ,132
    ,133
    ,136
    ,139
    ,142
    ,144
    ,147
    ,149
    ,151
    ,153
    ,156
    ,158
    ,160
    ,162
    ,164
    ,167
    ,169
    ,171
    ,173
    ,175
    ,178
    ,180
    ,181
    ,183
    ,185
    ,187
    ,188
    ,190
    ,192
    ,193
    ,195
    ,197
    ,198
    ,199
    ,201
    ,202
    ,203
    ,204
    ,205
    ,206
    ,207
    ,208
    ,209
    ,210
    ,211
    ,211
    ,212
    ,213
    ,213
    ,213
    ,214
    ,214
    ,214
    ,214
    ,214
    ,214
    ,214
    ,214
    ,213
    ,213
    ,213
    ,212
    ,211
    ,211
    ,210
    ,210
    ,209
    ,208
    ,207
    ,206
    ,205
    ,204
    ,203
    ,202
    ,201
    ,199
    ,198
    ,197
    ,196
    ,195
    ,193
    ,191
    ,190
    ,188
    ,186
    ,185
    ,183
    ,181
    ,179
    ,178
    ,176
    ,173
    ,172
    ,170
    ,167
    ,165
    ,163
    ,161
    ,159
    ,157
    ,155
    ,152
    ,151
    ,148
    ,146
    ,143
    ,141
    ,139
    ,137
    ,134
    ,132
    ,130
    ,127
    ,125
    ,123
    ,121
    ,118
    ,116
    ,114
    ,112
    ,110
    ,107
    ,105
    ,103
    ,100
    ,98
    ,96
    ,93
    ,92
    ,89
    ,87
    ,85
    ,83
    ,81
    ,80
    ,77
    ,75
    ,73
    ,72
    ,71
    ,68
    ,66
    ,65
    ,63
    ,61
    ,60
    ,58
    ,57
    ,56
    ,54
    ,52
    ,51
    ,50
    ,49
    ,47
    ,47
    ,46
    ,45
    ,43
    ,43
    ,42
    ,41
    ,40
    ,39
    ,39
    ,39
    ,39
    ,38
    ,37
    ,37
    ,37
    ,37
    ,37
    ,36
    ,36
    ,36
    ,36
    ,37
    ,37
    ,37
    ,38
    ,38
    ,38
    ,38
    ,40
    ,40
    ,41
    ,41
    ,42
    ,43
    ,44
    ,45
    ,46
    ,47
    ,48
    ,48
    ,50
    ,51
    ,52
    ,54
    ,55
    ,56
    ,57
    ,59
    ,61
    ,62
    ,63
    ,65
    ,67
    ,68
    ,70
    ,72
    ,74
    ,76
    ,77
    ,79
    ,80
    ,82
    ,84
    ,86
    ,88
    ,90
    ,93
    ,94
    ,97
    ,99
    ,101
    ,103
    ,105
    ,106
    ,109
    ,111
    ,113
    ,115
    ,117
    ,119
    ,121
    ,124
    ,126
    ,128
    ,131
    ,133
    ,134
    ,137
    ,139
    ,140
    ,143
    ,145
    ,147
    ,149
    ,151
    ,153
    ,155
    ,157
    ,159
    ,161
    ,163
    ,165
    ,167
    ,169
    ,171
    ,173
    ,174
    ,176
    ,178
    ,180
    ,182
    ,183
    ,184
    ,186
    ,188
    ,189
    ,191
    ,192
    ,193
    ,194
    ,196
    ,197
    ,199
    ,200
    ,201
    ,202
    ,203
    ,204
    ,205
    ,206
    ,207
    ,208
    ,209
    ,209
    ,210
    ,211
    ,212
    ,212
    ,212
    ,213
    ,213
    ,214
    ,214
    ,214
    ,215
    ,215
    ,215
    ,216
    ,215
    ,215
    ,215
    ,215
    ,215
    ,215
    ,215
    ,214
    ,214
    ,214
    ,213
    ,212
    ,212
    ,212
    ,210
    ,210
    ,209
    ,208
    ,208
    ,207
    ,205
    ,205
    ,204
    ,203
    ,202
    ,201
    ,200
    ,198
    ,197
    ,196
    ,195
    ,193
    ,192
    ,191
    ,190
    ,188
    ,187
    ,185
    ,184
    ,182
    ,181
    ,179
    ,177
    ,176
    ,174
    ,172
    ,170
    ,169
    ,167
    ,165
    ,164
    ,161
    ,160
    ,158
    ,157
    ,154
    ,153
    ,150
    ,149
    ,147
    ,145
    ,143
    ,141
    ,139
    ,137
    ,135
    ,133
    ,131
    ,129
    ,127
    ,125
    ,123
    ,122
    ,120
    ,118
    ,116
    ,114
    ,112
    ,109
    ,108
    ,106
    ,104
    ,102
    ,101
    ,98
    ,96
    ,95
    ,93
    ,92
    ,90
    ,87
    ,86
    ,84
    ,82
    ,81
    ,79
    ,78
    ,76
    ,74
    ,73
    ,71
    ,70
    ,69
    ,67
    ,66
    ,65
    ,63
    ,61
    ,60
    ,59
    ,58
    ,57
    ,55
    ,54
    ,53
    ,52
    ,51
    ,50
    ,49
    ,48
    ,47
    ,47
    ,45
    ,45
    ,44
    ,43
    ,43
    ,42
    ,42
    ,41
    ,40
    ,41
    ,40
    ,39
    ,39
    ,39
    ,39
    ,38
    ,39
    ,38
    ,38
    ,38
    ,38
    ,38
    ,39
    ,38
    ,39
    ,39
    ,39
    ,40
    ,40
    ,40
    ,40
    ,41
    ,41
    ,42
    ,42
    ,43
    ,44
    ,44
    ,45
    ,46
    ,46
    ,48
    ,48
    ,49
    ,51
    ,51
    ,53
    ,54
    ,54
    ,56
    ,57
    ,58
    ,59
    ,60
    ,62
    ,63
    ,64
    ,65
    ,67
    ,68
    ,69
    ,71
    ,72
    ,74
    ,75
    ,77
    ,78
    ,80
    ,81
    ,82
    ,85
    ,86
    ,87
    ,89
    ,91
    ,93
    ,94
    ,95
    ,98
    ,100
    ,101
    ,103
    ,104
    ,106
    ,108
    ,110
    ,111
    ,113
    ,115
    ,117
    ,119
    ,120
    ,123
    ,124
    ,126
    ,128
    ,129
    ,131
    ,133
    ,135
    ,137
    ,139
    ,140
    ,142
    ,144
    ,146
    ,148
    ,149
    ,151
    ,152
    ,154
    ,156
    ,157
    ,159
    ,161
    ,163
    ,164
    ,166
    ,167
    ,169
    ,171
    ,173
    ,174
    ,175
    ,176
    ,179
    ,180
    ,181
    ,182
    ,184
    ,185
    ,186
    ,188
    ,189
    ,190
    ,192
    ,193
    ,194
    ,195
    ,197
    ,198
    ,198
    ,199
    ,200
    ,202
    ,202
    ,203
    ,204
    ,205
    ,206
    ,206
    ,208
    ,208
    ,209
    ,210
    ,210
    ,210
    ,211
    ,212
    ,213
    ,213
    ,214
    ,214
    ,214
    ,214
    ,215
    ,215
    ,216
    ,215
    ,216
    ,216
    ,216
    ,216
    ,216
    ,216
    ,216
    ,216
    ,216
    ,216
    ,215
    ,216
    ,215
    ,215
    ,214
    ,214
    ,214
    ,213
    ,212
    ,212
    ,212
    ,211
    ,211
    ,210
    ,209
    ,209
    ,208
    ,207
    ,207
    ,205
    ,205
    ,204
    ,203
    ,202
    ,201
    ,200
    ,199
    ,198
    ,198
    ,196
    ,195
    ,194
    ,193
    ,192
    ,190
    ,190
    ,188
    ,187
    ,185
    ,184
    ,183
    ,182
    ,180
    ,179
    ,178
    ,176
    ,175
    ,174
    ,172
    ,171
    ,170
    ,168
    ,167
    ,165
    ,164
    ,162
    ,160
    ,159
    ,157
    ,155
    ,154
    ,153
    ,151
    ,149
    ,148
    ,147
    ,145
    ,143
    ,141
    ,140
    ,138
    ,137
    ,135
    ,134
    ,132
    ,130
    ,129
    ,127
    ,125
    ,123
    ,122
    ,120
    ,119
    ,117
    ,116
    ,114
    ,112
    ,110
    ,110
    ,107
    ,106
    ,104
    ,102
    ,101
    ,100
    ,98
    ,96
    ,95
    ,93
    ,92
    ,90
    ,89
    ,87
    ,86
    ,85
    ,84
    ,82
    ,81
    ,80
    ,78
    ,76
    ,75
    ,74
    ,73
    ,72
    ,70
    ,69
    ,67
    ,66
    ,65
    ,64
    ,63
    ,62
    ,61
    ,60
    ,59
    ,58
    ,57
    ,56
    ,55
    ,54
    ,53
    ,52
    ,51
    ,50
    ,50
    ,49
    ,49
    ,47
    ,47
    ,46
    ,45
    ,45
    ,45
    ,44
    ,44
    ,42
    ,42
    ,42
    ,41
    ,41
    ,41
    ,41
    ,40
    ,40
    ,40
    ,40
    ,39
    ,39
    ,38
    ,38
    ,38
    ,38
    ,39
    ,38
    ,38
    ,39
    ,39
    ,39
    ,39
    ,39
    ,39
    ,39
    ,40
    ,40
    ,40
    ,40
    ,41
    ,42
    ,42
    ,42
    ,42
    ,43
    ,44
    ,44
    ,45
    ,45
    ,46
    ,47
    ,47
    ,48
    ,49
    ,50
    ,51
    ,51
    ,52
    ,53
    ,54
    ,55
    ,56
    ,57
    ,57
    ,59
    ,60
    ,61
    ,62
    ,63
    ,64
    ,65
    ,66
    ,67
    ,68
    ,69
    ,71
    ,72
    ,72
    ,73
    ,75
    ,76
    ,77
    ,79
    ,80
    ,81
    ,83
    ,84
    ,85
    ,86
    ,88
    ,89
    ,90
    ,92
    ,93
    ,95
    ,96
    ,98
    ,99
    ,100
    ,102
    ,103
    ,104
    ,106
    ,108
    ,109
    ,110
    ,112
    ,114
    ,115
    ,116
    ,118
    ,119
    ,120
    ,122
    ,124
    ,125
    ,126
    ,128
    ,129
    ,130
    ,133
    ,134
    ,135
    ,137
    ,138
    ,140
    ,141
    ,143
    ,144
    ,145
    ,147
    ,148
    ,149
    ,151
    ,152
    ,154
    ,155
    ,156
    ,158
    ,159
    ,161
    ,162
    ,164
    ,164
    ,166
    ,168
    ,169
    ,170
    ,172
    ,173
    ,174
    ,175
    ,176
    ,178
    ,179
    ,180
    ,181
    ,182
    ,183
    ,184
    ,185
    ,186
    ,187
    ,189
    ,190
    ,191
    ,192
    ,192
    ,193
    ,194
    ,196
    ,196
    ,197
    ,198
    ,198
    ,199
    ,200
    ,201
    ,202
    ,203
    ,204
    ,204
    ,205
    ,206
    ,206
    ,207
    ,207
    ,208
    ,208
    ,209
    ,210
    ,210
    ,210
    ,211
    ,211
    ,212
    ,212
    ,213
    ,213
    ,213
    ,214
    ,214
    ,214
    ,215
    ,215
    ,214
    ,215
    ,215
    ,215
    ,216
    ,215
    ,215
    ,215
    ,215
    ,216
    ,215
    ,215
    ,215
    ,215
    ,215
    ,215
    ,215
    ,214
    ,214
    ,214
    ,214
    ,214
    ,213
    ,213
    ,213
    ,212
    ,211
    ,211
    ,211
    ,210
    ,210
    ,209
    ,209
    ,208
    ,207
    ,207
    ,207
    ,206
    ,205
    ,204
    ,204
    ,203
    ,202
    ,201
    ,201
    ,200
    ,199
    ,198
    ,197
    ,197
    ,196
    ,195
    ,194
    ,193
    ,192
    ,191
    ,190
    ,189
    ,188
    ,188
    ,186
    ,185
    ,184
    ,184
    ,182
    ,182
    ,180
    ,179
    ,178
    ,177
    ,176
    ,175
    ,173
    ,172
    ,172
    ,170
    ,168
    ,168
    ,167
    ,165
    ,164
    ,162
    ,162
    ,161
    ,159
    ,157
    ,156
    ,155
    ,154
    ,153
    ,152
    ,150
    ,149
    ,148
    ,146
    ,145
    ,144
    ,142
    ,142
    ,140
    ,139
    ,137
    ,136
    ,135
    ,134
    ,132
    ,131
    ,130
    ,128
    ,127
    ,125
    ,124
    ,123
    ,122
    ,121
    ,119
    ,118
    ,117
    ,116
    ,114
    ,113
    ,111
    ,110
    ,109
    ,108
    ,107
    ,105
    ,103
    ,103
    ,101
    ,100
    ,99
    ,98
    ,97
    ,96
    ,94
    ,93
    ,92
    ,91
    ,89
    ,88
    ,87
    ,86
    ,85
    ,84
    ,83
    ,81
    ,81
    ,80
    ,79
    ,77
    ,76
    ,75
    ,74
    ,73
    ,72
    ,71
    ,70
    ,70
    ,68
    ,67
    ,66
    ,65
    ,64
    ,64
    ,63
    ,62
    ,61
    ,60
    ,60
    ,58
    ,58
    ,57
    ,56
    ,56
    ,55
    ,54
    ,53
    ,53
    ,52
    ,51
    ,51
    ,50
    ,50
    ,49
    ,48
    ,48
    ,47
    ,47
    ,47
    ,46
    ,45
    ,45
    ,44
    ,45
    ,44
    ,43
    ,43
    ,43
    ,43
    ,42
    ,42
    ,42
    ,41
    ,41
    ,41
    ,41
    ,41
    ,40
    ,40
    ,40
    ,40
    ,40
    ,39
    ,40
    ,40
    ,39
    ,39
    ,40
    ,39
    ,39
    ,40
    ,40
    ,40
    ,40
    ,40
    ,40
    ,40
    ,41
    ,41
    ,41
    ,41
    ,42
    ,42
    ,42
    ,42
    ,42
    ,43
    ,43
    ,43
    ,43
    ,44
    ,44
    ,45
    ,46
    ,46
    ,46
    ,47
    ,48
    ,48
    ,48
    ,49
    ,50
    ,51
    ,51
    ,52
    ,52
    ,53
    ,54
    ,54
    ,55
    ,55
    ,56
    ,57
    ,58
    ,58
    ,59
    ,61
    ,61
    ,61
    ,63
    ,63
    ,64
    ,65
    ,66
    ,67
    ,68
    ,69
    ,70
    ,71
    ,72
    ,72
    ,73
    ,74
    ,75
    ,76
    ,77
    ,78
    ,79
    ,80
    ,81
    ,82
    ,83
    ,84
    ,85
    ,86
    ,87
    ,89
    ,89
    ,90
    ,91
    ,92
    ,93
    ,94
    ,96
    ,97
    ,98
    ,98
    ,100
    ,102
    ,102
    ,104
    ,104
    ,106
    ,107
    ,108
    ,109
    ,110
    ,111
    ,112
    ,113
    ,115
    ,116
    ,117
    ,118
    ,119
    ,120
    ,121
    ,122
    ,124
    ,125
    ,126
    ,127
    ,128
    ,130
    ,130
    ,131
    ,133
    ,133
    ,135
    ,136
    ,137
    ,139
    ,140
    ,141
    ,142
    ,143
    ,144
    ,145
    ,146
    ,147
    ,148
    ,149
    ,150
    ,151
    ,153
    ,154
    ,154
    ,155
    ,156
    ,158
    ,159
    ,160
    ,161
    ,162
    ,163
    ,164
    ,165
    ,166
    ,167
    ,168
    ,169
    ,170
    ,171
    ,171
    ,173
    ,174
    ,175
    ,176
    ,176
    ,178
    ,178
    ,179
    ,179
    ,180
    ,182
    ,183
    ,183
    ,184
    ,185
    ,186
    ,186
    ,187
    ,188
    ,188
    ,190
    ,190
    ,191
    ,192
    ,192
    ,193
    ,194
    ,194
    ,195
    ,196
    ,196
    ,197
    ,198
    ,199
    ,199
    ,200
    ,200
    ,201
    ,202
    ,202
    ,202
    ,203
    ,203
    ,204
    ,204
    ,205
    ,205
    ,206
    ,206
    ,206
    ,207
    ,207
    ,208
    ,208
    ,208
    ,208
    ,209
    ,210
    ,210
    ,210
    ,211
    ,211
    ,210
    ,211
    ,211
    ,212
    ,211
    ,212
    ,212
    ,212
    ,212
    ,212
    ,213
    ,213
    ,212
    ,212
    ,212
    ,213
    ,213
    ,213
    ,213
    ,213
    ,213
    ,213
    ,213
    ,212
    ,213
    ,212
    ,212
    ,213
    ,213
    ,213
    ,212
    ,212
    ,212
    ,212
    ,211
    ,211
    ,211
    ,210
    ,211
    ,211
    ,210
    ,210
    ,210
    ,209
    ,209
    ,209
    ,208
    ,208
    ,207
    ,207
    ,207
    ,206
    ,206
    ,206
    ,205
    ,204
    ,204
    ,204
    ,203
    ,202
    ,202
    ,201
    ,201
    ,201
    ,200
    ,199
    ,199
    ,198
    ,198
    ,197
    ,197
    ,195
    ,195
    ,195
    ,194
    ,193
    ,192
    ,192
    ,191
    ,190
    ,190
    ,188
    ,188
    ,187
    ,187
    ,186
    ,185
    ,184
    ,184
    ,183
    ,183
    ,181
    ,180
    ,179
    ,179
    ,178
    ,177
    ,177
    ,175
    ,174
    ,173
    ,172
    ,172
    ,171
    ,170
    ,169
    ,168
    ,168
    ,166
    ,166
    ,165
    ,164
    ,164
    ,162
    ,162
    ,160
    ,160
    ,159
    ,158
    ,157
    ,156
    ,155
    ,154
    ,153
    ,152
    ,152
    ,150
    ,149
    ,149
    ,148
    ,146
    ,146
    ,145
    ,144
    ,143
    ,142
    ,141
    ,140
    ,139
    ,138
    ,137
    ,136
    ,136
    ,135
    ,133
    ,132
    ,131
    ,131
    ,129
    ,128
    ,128
    ,127
    ,126
    ,124
    ,124
    ,123
    ,122
    ,122
    ,120
    ,119
    ,118
    ,117
    ,116
    ,115
    ,115
    ,114
    ,112
    ,112
    ,111
    ,110
    ,109
    ,108
    ,107
    ,107
    ,106
    ,104
    ,104
    ,103
    ,102
    ,101
    ,100
    ,99
    ,98
    ,98
    ,97
    ,96
    ,95
    ,94
    ,93
    ,93
    ,92
    ,91
    ,90
    ,89
    ,88
    ,87
    ,87
    ,86
    ,85
    ,84
    ,84
    ,83
    ,82
    ,81
    ,80
    ,80
    ,79
    ,78
    ,78
    ,77
    ,76
    ,75
    ,75
    ,74
    ,73
    ,73
    ,72
    ,71
    ,71
    ,70
    ,70
    ,68
    ,68
    ,68
    ,67
    ,66
    ,66
    ,64
    ,64
    ,64
    ,63
    ,63
    ,62
    ,62
    ,61
    ,60
    ,60
    ,59
    ,59
    ,58
    ,58
    ,57
    ,57
    ,57
    ,56
    ,56
    ,55
    ,55
    ,55
    ,54
    ,53
    ,53
    ,53
    ,53
    ,52
    ,52
    ,51
    ,51
    ,51
    ,50
    ,50
    ,50
    ,50
    ,49
    ,48
    ,49
    ,48
    ,48
    ,48
    ,47
    ,47
    ,47
    ,47
    ,46
    ,46
    ,46
    ,46
    ,46
    ,46
    ,46
    ,46
    ,46
    ,45
    ,46
    ,45
    ,45
    ,45
    ,45
    ,45
    ,45
    ,45
    ,45
    ,45
    ,45
    ,45
    ,45
    ,45
    ,45
    ,45
    ,45
    ,45
    ,45
    ,45
    ,45
    ,45
    ,45
    ,45
    ,45
    ,46
    ,46
    ,46
    ,46
    ,46
    ,47
    ,47
    ,47
    ,46
    ,47
    ,47
    ,47
    ,48
    ,48
    ,48
    ,48
    ,49
    ,49
    ,49
    ,49
    ,50
    ,51
    ,50
    ,50
    ,51
    ,51
    ,52
    ,52
    ,52
    ,53
    ,53
    ,53
    ,54
    ,54
    ,54
    ,55
    ,55
    ,56
    ,56
    ,57
    ,57
    ,58
    ,58
    ,59
    ,59
    ,59
    ,60
    ,60
    ,61
    ,61
    ,62
    ,63
    ,63
    ,64
    ,64
    ,65
    ,65
    ,66
    ,66
    ,67
    ,67
    ,68
    ,69
    ,69
    ,70
    ,70
    ,71
    ,71
    ,72
    ,73
    ,73
    ,74
    ,75
    ,75
    ,76
    ,77
    ,77
    ,78
    ,79
    ,79
    ,80
    ,81
    ,81
    ,82
    ,83
    ,83
    ,84
    ,85
    ,86
    ,87
    ,87
    ,88
    ,88
    ,90
    ,90
    ,90
    ,91
    ,92
    ,93
    ,93
    ,94
    ,95
    ,96
    ,96
    ,97
    ,98
    ,99
    ,100
    ,100
    ,101
    ,102
    ,103
    ,103
    ,104
    ,104
    ,105
    ,106
    ,107
    ,107
    ,109
    ,109
    ,110
    ,111
    ,111
    ,112
    ,113
    ,114
    ,114
    ,115
    ,116
    ,117
    ,117
    ,118
    ,119
    ,120
    ,120
    ,121
    ,122
    ,123
    ,124
    ,124
    ,125
    ,125
    ,127
    ,127
    ,128
    ,129
    ,129
    ,130
    ,131
    ,132
    ,133
    ,133
    ,134
    ,135
    ,135
    ,136
    ,137
    ,138
    ,138
    ,139
    ,139
    ,141
    ,142
    ,141
    ,143
    ,144
    ,144
    ,145
    ,146
    ,146
    ,147
    ,148
    ,148
    ,149
    ,150
    ,150
    ,151
    ,151
    ,152
    ,153
    ,153
    ,154
    ,155
    ,155
    ,157
    ,157
    ,157
    ,158
    ,159
    ,159
    ,160
    ,161
    ,161
    ,162
    ,163
    ,163
    ,164
    ,164
    ,165
    ,166
    ,166
    ,167
    ,168
    ,168
    ,168
    ,169
    ,170
    ,170
    ,171
    ,171
    ,172
    ,173
    ,173
    ,173
    ,174
    ,174
    ,175
    ,176
    ,176
    ,176
    ,177
    ,177
    ,178
    ,179
    ,180
    ,180
    ,180
    ,181
    ,181
    ,181
    ,182
    ,183
    ,183
    ,184
    ,184
    ,184
    ,185
    ,185
    ,186
    ,186
    ,187
    ,187
    ,187
    ,187
    ,188
    ,188
    ,189
    ,189
    ,189
    ,190
    ,190
    ,190
    ,191
    ,191
    ,192
    ,192
    ,192
    ,192
    ,192
    ,193
    ,193
    ,194
    ,194
    ,195
    ,194
    ,195
    ,195
    ,195
    ,195
    ,196
    ,196
    ,196
    ,197
    ,197
    ,197
    ,198
    ,197
    ,198
    ,198
    ,198
    ,198
    ,198
    ,198
    ,198
    ,199
    ,199
    ,199
    ,199
    ,200
    ,200
    ,200
    ,200
    ,200
    ,200
    ,200
    ,200
    ,200
    ,200
    ,201
    ,200
    ,201
    ,201
    ,201
    ,201
    ,201
    ,201
    ,201
    ,201
    ,201
    ,201
    ,201
    ,201
    ,201
    ,201
    ,201
    ,201
    ,201
    ,201
    ,201
    ,201
    ,201
    ,201
    ,201
    ,201
    ,201
    ,201
    ,200
    ,201
    ,201
    ,200
    ,201
    ,200
    ,200
    ,200
    ,199
    ,200
    ,200
    ,200
    ,200
    ,200
    ,199
    ,199
    ,199
    ,198
    ,198
    ,198
    ,199
    ,198
    ,198
    ,197
    ,197
    ,197
    ,197
    ,197
    ,197
    ,196
    ,196
    ,196
    ,196
    ,196
    ,195
    ,195
    ,194
    ,194
    ,194
    ,194
    ,194
    ,194
    ,193
    ,193
    ,193
    ,192
    ,192
    ,191
    ,191
    ,192
    ,190
    ,190
    ,190
    ,190
    ,189
    ,189
    ,189
    ,188
    ,188
    ,188
    ,188
    ,187
    ,187
    ,187
    ,187
    ,185
    ,185
    ,185
    ,184
    ,184
    ,184
    ,183
    ,183
    ,182
    ,183
    ,182
    ,182
    ,181
    ,181
    ,180
    ,180
    ,179
    ,179
    ,178
    ,178
    ,177
    ,177
    ,177
    ,177
    ,176
    ,176
    ,175
    ,175
    ,175
    ,174
    ,174
    ,173
    ,172
    ,172
    ,171
    ,171
    ,170
    ,170
    ,170
    ,169
    ,169
    ,168
    ,168
    ,167
    ,167
    ,167
    ,166
    ,165
    ,164
    ,164
    ,164
    ,163
    ,163
    ,162
    ,162
    ,161
    ,161
    ,160
    ,160
    ,159
    ,159
    ,159
    ,158
    ,157
    ,157
    ,156
    ,156
    ,156
    ,154
    ,155
    ,153
    ,153
    ,153
    ,152
    ,152
    ,151
    ,150
    ,150
    ,149
    ,149
    ,148
    ,148
    ,148
    ,147
    ,147
    ,145
    ,145
    ,145
    ,144
    ,143
    ,143
    ,142
    ,142
    ,142
    ,141
    ,140
    ,140
    ,139
    ,139
    ,139
    ,137
    ,137
    ,137
    ,136
    ,135
    ,135
    ,134
    ,134
    ,133
    ,133
    ,133
    ,132
    ,132
    ,131
    ,130
    ,130
    ,129
    ,129
    ,128
    ,127
    ,128
    ,127
    ,126
    ,125
    ,125
    ,125
    ,124
    ,124
    ,124
    ,123
    ,122
    ,121
    ,121
    ,121
    ,120
    ,120
    ,119
    ,119
    ,118
    ,117
    ,117
    ,117
    ,116
    ,116
    ,115
    ,115
    ,115
    ,114
    ,113
    ,113
    ,113
    ,112
    ,111
    ,111
    ,110
    ,110
    ,110
    ,110
    ,109
    ,108
    ,108
    ,107
    ,106
    ,106
    ,106
    ,105
    ,105
    ,105
    ,105
    ,103
    ,104
    ,103
    ,103
    ,101
    ,102
    ,101
    ,101
    ,100
    ,100
    ,99
    ,99
    ,99
    ,98
    ,98
    ,97
    ,97
    ,97
    ,96
    ,96
    ,96
    ,95
    ,95
    ,95
    ,95
    ,94
    ,93
    ,93
    ,93
    ,93
    ,92
    ,92
    ,91
    ,91
    ,91
    ,90
    ,90
    ,89
    ,89
    ,89
    ,88
    ,88
    ,88
    ,88
    ,87
    ,87
    ,87
    ,86
    ,86
    ,86
    ,85
    ,85
    ,85
    ,85
    ,85
    ,84
    ,84
    ,84
    ,83
    ,83
    ,83
    ,82
    ,82
    ,82
    ,82
    ,82
    ,81
    ,81
    ,80
    ,80
    ,80
    ,80
    ,80
    ,79
    ,79
    ,79
    ,79
    ,79
    ,78
    ,78
    ,77
    ,78
    ,78
    ,77
    ,77
    ,77
    ,76
    ,77
    ,76
    ,76
    ,76
    ,76
    ,75
    ,75
    ,75
    ,75
    ,74
    ,74
    ,75
    ,74
    ,74
    ,74
    ,73
    ,73
    ,73
    ,73
    ,74
    ,73
    ,72
    ,73
    ,73
    ,72
    ,73
    ,73
    ,73
    ,72
    ,72
    ,72
    ,72
    ,72
    ,71
    ,71
    ,72
    ,72
    ,72
    ,71
    ,71
    ,71
    ,71
    ,71
    ,70
    ,71
    ,70
    ,71
    ,71
    ,71
    ,71
    ,70
    ,70
    ,70
    ,70
    ,71
    ,71
    ,70
    ,70
    ,70
    ,70
    ,70
    ,70
    ,70
    ,71
    ,70
    ,70
    ,70
    ,70
    ,70
    ,71
    ,71
    ,70
    ,70
    ,70
    ,70
    ,70
    ,70
    ,70
    ,70
    ,70
    ,70
    ,70
    ,71
    ,70
    ,71
    ,70
    ,71
    ,71
    ,71
    ,71
    ,71
    ,71
    ,71
    ,71
    ,71
    ,71
    ,72
    ,72
    ,71
    ,72
    ,71
    ,72
    ,72
    ,72
    ,72
    ,72
    ,72
    ,72
    ,73
    ,72
    ,72
    ,73
    ,73
    ,73
    ,73
    ,73
    ,73
    ,74
    ,73
    ,74
    ,74
    ,74
    ,75
    ,74
    ,75
    ,74
    ,75
    ,75
    ,75
    ,75
    ,75
    ,76
    ,76
    ,76
    ,76
    ,76
    ,76
    ,76
    ,76
    ,77
    ,77
    ,78
    ,78
    ,78
    ,78
    ,78
    ,78
    ,78
    ,78
    ,78
    ,79
    ,79
    ,79
    ,79
    ,79
    ,79
    ,80
    ,80
    ,81
    ,81
    ,81
    ,81
    ,81
    ,81
    ,81
    ,82
    ,82
    ,82
    ,82
    ,83
    ,83
    ,83
    ,83
    ,84
    ,83
    ,84
    ,84
    ,85
    ,84
    ,85
    ,85
    ,85
    ,85
    ,86
    ,86
    ,87
    ,87
    ,86
    ,87
    ,87
    ,87
    ,87
    ,88
    ,88
    ,88
    ,89
    ,89
    ,89
    ,89
    ,90
    ,90
    ,90
    ,90
    ,91
    ,91
    ,91
    ,92
    ,92
    ,92
    ,92
    ,92
    ,93
    ,93
    ,93
    ,93
    ,94
    ,94
    ,95
    ,95
    ,95
    ,95
    ,95
    ,95
    ,96
    ,96
    ,96
    ,97
    ,97
    ,97
    ,97
    ,98
    ,98
    ,98
    ,98
    ,99
    ,100
    ,100
    ,100
    ,100
    ,101
    ,101
    ,101
    ,101
    ,101
    ,102
    ,102
    ,102
    ,102
    ,103
    ,103
    ,104
    ,104
    ,104
    ,104
    ,104
    ,105
    ,105
    ,105
    ,106
    ,106
    ,106
    ,106
    ,107
    ,107
    ,107
    ,107
    ,108
    ,108
    ,108
    ,108
    ,109
    ,109
    ,109
    ,110
    ,110
    ,110
    ,111
    ,111
    ,111
    ,112
    ,112
    ,112
    ,112
    ,113
    ,113
    ,113
    ,113
    ,113
    ,114
    ,114
    ,115
    ,115
    ,115
    ,115
    ,116
    ,116
    ,116
    ,117
    ,116
    ,117
    ,117
    ,117
    ,118
    ,118
    ,118
    ,118
    ,119
    ,119
    ,119
    ,120
    ,120
    ,120
    ,120
    ,121
    ,121
    ,122
    ,121
    ,122
    ,122
    ,122
    ,122
    ,123
    ,123
    ,123
    ,123
    ,124
    ,124
    ,125
    ,125
    ,125
    ,125
    ,125
    ,126
    ,126
    ,126
    ,126
    ,126
    ,127
    ,127
    ,127
    ,127
    ,128
    ,128
    ,128
    ,129
    ,129
    ,129
    ,129
    ,129
    ,129
    ,130
    ,130
    ,130
    ,131
    ,131
    ,131
    ,132
    ,131
    ,132
    ,132
    ,132
    ,132
    ,132
    ,133
    ,133
    ,133
    ,134
    ,134
    ,134
    ,134
    ,135
    ,134
    ,135
    ,135
    ,135
    ,135
    ,135
    ,136
    ,136
    ,136
    ,137
    ,137
    ,137
    ,137
    ,138
    ,137
    ,138
    ,138
    ,138
    ,139
    ,138
    ,139
    ,139
    ,139
    ,139
    ,140
    ,140
    ,140
    ,140
    ,140
    ,141
    ,141
    ,141
    ,141
    ,141
    ,142
    ,142
    ,142
    ,142
    ,142
    ,143
    ,142
    ,143
    ,143
    ,143
    ,143
    ,143
    ,143
    ,143
    ,144
    ,144
    ,144
    ,144
    ,144
    ,144
    ,145
    ,145
    ,145
    ,145
    ,146
    ,146
    ,146
    ,146
    ,146
    ,146
    ,146
    ,146
    ,147
    ,147
    ,147
    ,147
    ,148
    ,147
    ,147
    ,148
    ,148
    ,148
    ,148
    ,149
    ,148
    ,149
    ,149
    ,149
    ,149
    ,149
    ,149
    ,149
    ,149
    ,150
    ,150
    ,150
    ,150
    ,150
    ,150
    ,150
    ,150
    ,151
    ,151
    ,151
    ,151
    ,151
    ,151
    ,151
    ,151
    ,151
    ,152
    ,152
    ,152
    ,152
    ,152
    ,151
    ,152
    ,152
    ,152
    ,152
    ,153
    ,153
    ,153
    ,153
    ,153
    ,153
    ,153
    ,153
    ,153
    ,153
    ,153
    ,153
    ,153
    ,153
    ,153
    ,154
    ,154
    ,154
    ,154
    ,154
    ,154
    ,154
    ,154
    ,154
    ,154
    ,154
    ,155
    ,154
    ,154
    ,154
    ,154
    ,154
    ,155
    ,154
    ,154
    ,155
    ,155
    ,155
    ,155
    ,155
    ,155
    ,155
    ,155
    ,155
    ,156
    ,155
    ,155
    ,155
    ,155
    ,155
    ,156
    ,155
    ,155
    ,156
    ,155
    ,155
    ,155
    ,156
    ,155
    ,156
    ,156
    ,156
    ,155
    ,155
    ,156
    ,156
    ,156
    ,156
    ,156
    ,156
    ,156
    ,156
    ,156
    ,155
    ,156
    ,156
    ,156
    ,156
    ,156
    ,156
    ,156
    ,156
    ,156
    ,156
    ,156
    ,156
    ,156
    ,156
    ,156
    ,156
    ,156
    ,156
    ,155
    ,155
    ,156
    ,155
    ,156
    ,155
    ,156
    ,156
    ,156
    ,156
    ,156
    ,155
    ,156
    ,156
    ,155
    ,155
    ,155
    ,155
    ,155
    ,156
    ,155
    ,155
    ,155
    ,156
    ,155
    ,155
    ,155
    ,155
    ,155
    ,155
    ,155
    ,155
    ,155
    ,155
    ,155
    ,155
    ,155
    ,155
    ,154
    ,154
    ,155
    ,154
    ,154
    ,155
    ,155
    ,154
    ,155
    ,155
    ,154
    ,154
    ,154
    ,154
    ,154
    ,154
    ,154
    ,154
    ,154
    ,154
    ,154
    ,154
    ,154
    ,153
    ,154
    ,154
    ,153
    ,153
    ,153
    ,153
    ,153
    ,153
    ,153
    ,153
    ,153
    ,153
    ,153
    ,153
    ,152
    ,152
    ,153
    ,153
    ,153
    ,152
    ,152
    ,152
    ,152
    ,152
    ,152
    ,152
    ,152
    ,152
    ,152
    ,152
    ,152
    ,152
    ,151
    ,151
    ,151
    ,152
    ,151
    ,151
    ,151
    ,151
    ,151
    ,151
    ,151
    ,151
    ,151
    ,151
    ,150
    ,150
    ,150
    ,150
    ,150
    ,150
    ,150
    ,150
    ,149
    ,149
    ,150
    ,149
    ,150
    ,149
    ,150
    ,149
    ,149
    ,149
    ,149
    ,149
    ,149
    ,149
    ,148
    ,148
    ,149
    ,148
    ,148
    ,148
    ,148
    ,148
    ,148
    ,148
    ,148
    ,148
    ,148
    ,148
    ,148
    ,148
    ,148
    ,147
    ,147
    ,148
    ,147
    ,147
    ,147
    ,147
    ,147
    ,147
    ,147
    ,146
    ,146
    ,146
    ,146
    ,146
    ,146
    ,146
    ,146
    ,145
    ,146
    ,145
    ,145
    ,145
    ,145
    ,145
    ,145
    ,145
    ,144
    ,144
    ,145
    ,144
    ,144
    ,144
    ,144
    ,144
    ,144
    ,144
    ,144
    ,144
    ,144
    ,144
    ,143
    ,143
    ,143
    ,143
    ,143
    ,143
    ,143
    ,143
    ,143
    ,143
    ,143
    ,142
    ,142
    ,142
    ,142
    ,142
    ,142
    ,142
    ,142
    ,142
    ,141
    ,141
    ,142
    ,142
    ,141
    ,141
    ,141
    ,141
    ,141
    ,141
    ,141
    ,141
    ,141
    ,140
    ,140
    ,140
    ,140
    ,140
    ,140
    ,140
    ,140
    ,140
    ,139
    ,139
    ,139
    ,139
    ,139
    ,139
    ,139
    ,139
    ,139
    ,139
    ,138
    ,139
    ,138
    ,138
    ,138
    ,138
    ,138
    ,138
    ,138
    ,138
    ,138
    ,138
    ,138
    ,137
    ,137
    ,137
    ,137
    ,137
    ,137
    ,137
    ,137
    ,137
    ,137
    ,137
    ,137
    ,137
    ,137
    ,137
    ,136
    ,136
    ,136
    ,136
    ,136
    ,136
    ,136
    ,135
    ,135
    ,135
    ,135
    ,135
    ,135
    ,135
    ,135
    ,135
    ,135
    ,135
    ,135
    ,134
    ,134
    ,135
    ,135
    ,135
    ,134
    ,134
    ,134
    ,134
    ,134
    ,134
    ,133
    ,133
    ,133
    ,133
    ,133
    ,133
    ,133
    ,133
    ,133
    ,133
    ,133
    ,133
    ,133
    ,133
    ,132
    ,132
    ,132
    ,132
    ,132
    ,132
    ,132
    ,132
    ,132
    ,132
    ,132
    ,132
    ,132
    ,131
    ,131
    ,131
    ,131
    ,131
    ,132
    ,131
    ,131
    ,131
    ,131
    ,131
    ,131
    ,131
    ,131
    ,130
    ,131
    ,130
    ,130
    ,130
    ,130
    ,131
    ,130
    ,130
    ,130
    ,130
    ,130
    ,130
    ,130
    ,130
    ,130
    ,129
    ,129
    ,130
    ,129
    ,129
    ,129
    ,129
    ,129
    ,129
    ,128
    ,128
    ,129
    ,128
    ,128
    ,129
    ,129
    ,129
    ,129
    ,129
    ,129
    ,128
    ,129
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,127
    ,127
    ,127
    ,128
    ,127
    ,127
    ,127
    ,127
    ,127
    ,127
    ,127
    ,127
    ,127
    ,127
    ,126
    ,127
    ,127
    ,127
    ,127
    ,126
    ,127
    ,127
    ,126
    ,127
    ,126
    ,126
    ,126
    ,126
    ,126
    ,126
    ,126
    ,126
    ,126
    ,126
    ,126
    ,125
    ,126
    ,126
    ,126
    ,126
    ,125
    ,125
    ,125
    ,126
    ,125
    ,125
    ,125
    ,125
    ,125
    ,126
    ,125
    ,125
    ,125
    ,125
    ,125
    ,125
    ,125
    ,125
    ,125
    ,125
    ,125
    ,125
    ,125
    ,124
    ,124
    ,125
    ,124
    ,124
    ,124
    ,124
    ,125
    ,125
    ,124
    ,124
    ,124
    ,124
    ,124
    ,124
    ,124
    ,124
    ,125
    ,125
    ,125
    ,125
    ,125
    ,124
    ,124
    ,124
    ,124
    ,124
    ,124
    ,124
    ,123
    ,124
    ,123
    ,124
    ,124
    ,124
    ,124
    ,123
    ,123
    ,124
    ,124
    ,124
    ,124
    ,124
    ,123
    ,124
    ,124
    ,123
    ,123
    ,124
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,124
    ,123
    ,124
    ,124
    ,123
    ,123
    ,124
    ,124
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,122
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,122
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,124
    ,123
    ,124
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,122
    ,123
    ,123
    ,123
    ,123
    ,122
    ,122
    ,122
    ,122
    ,123
    ,122
    ,122
    ,122
    ,122
    ,122
    ,122
    ,121
    ,121
    ,121
    ,122
    ,122
    ,121
    ,122
    ,121
    ,121
    ,121
    ,121
    ,121
    ,121
    ,121
    ,121
    ,121
    ,121
    ,121
    ,121
    ,121
    ,121
    ,120
    ,120
    ,121
    ,121
    ,121
    ,121
    ,121
    ,120
    ,120
    ,120
    ,120
    ,120
    ,120
    ,120
    ,120
    ,120
    ,120
    ,120
    ,120
    ,120
    ,120
    ,120
    ,120
    ,120
    ,120
    ,119
    ,119
    ,119
    ,119
    ,119
    ,120
    ,119
    ,119
    ,120
    ,120
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,118
    ,118
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,118
    ,119
    ,119
    ,119
    ,119
    ,118
    ,119
    ,118
    ,119
    ,119
    ,119
    ,119
    ,119
    ,118
    ,119
    ,119
    ,119
    ,119
    ,119
    ,118
    ,119
    ,119
    ,119
    ,119
    ,118
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,118
    ,119
    ,119
    ,119
    ,119
    ,118
    ,119
    ,119
    ,119
    ,119
    ,118
    ,118
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,118
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,119
    ,120
    ,119
    ,120
    ,119
    ,119
    ,119
    ,119
    ,120
    ,120
    ,120
    ,119
    ,120
    ,119
    ,120
    ,119
    ,120
    ,120
    ,120
    ,120
    ,120
    ,120
    ,120
    ,120
    ,120
    ,120
    ,120
    ,120
    ,120
    ,120
    ,120
    ,120
    ,120
    ,120
    ,120
    ,120
    ,120
    ,120
    ,120
    ,120
    ,120
    ,120
    ,120
    ,120
    ,120
    ,121
    ,121
    ,120
    ,121
    ,121
    ,121
    ,121
    ,120
    ,121
    ,121
    ,121
    ,121
    ,121
    ,121
    ,121
    ,121
    ,121
    ,121
    ,121
    ,121
    ,121
    ,121
    ,121
    ,121
    ,121
    ,121
    ,121
    ,121
    ,122
    ,121
    ,121
    ,121
    ,122
    ,122
    ,121
    ,122
    ,121
    ,121
    ,122
    ,122
    ,122
    ,122
    ,122
    ,122
    ,121
    ,121
    ,122
    ,122
    ,122
    ,122
    ,122
    ,122
    ,122
    ,122
    ,122
    ,122
    ,122
    ,122
    ,122
    ,122
    ,123
    ,122
    ,122
    ,122
    ,122
    ,122
    ,122
    ,122
    ,122
    ,122
    ,122
    ,123
    ,123
    ,123
    ,122
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,123
    ,124
    ,123
    ,123
    ,123
    ,124
    ,124
    ,124
    ,123
    ,123
    ,124
    ,123
    ,123
    ,124
    ,123
    ,124
    ,124
    ,123
    ,124
    ,123
    ,124
    ,124
    ,124
    ,124
    ,124
    ,124
    ,124
    ,124
    ,124
    ,124
    ,124
    ,124
    ,124
    ,124
    ,124
    ,124
    ,124
    ,124
    ,124
    ,124
    ,124
    ,124
    ,125
    ,124
    ,124
    ,125
    ,125
    ,125
    ,125
    ,125
    ,125
    ,125
    ,125
    ,125
    ,125
    ,124
    ,125
    ,124
    ,125
    ,125
    ,125
    ,125
    ,124
    ,125
    ,125
    ,125
    ,125
    ,125
    ,125
    ,125
    ,125
    ,125
    ,125
    ,125
    ,125
    ,125
    ,125
    ,125
    ,125
    ,125
    ,125
    ,126
    ,125
    ,125
    ,125
    ,125
    ,126
    ,125
    ,125
    ,125
    ,126
    ,125
    ,125
    ,126
    ,126
    ,126
    ,126
    ,126
    ,126
    ,126
    ,126
    ,126
    ,126
    ,126
    ,126
    ,125
    ,126
    ,126
    ,126
    ,126
    ,126
    ,126
    ,126
    ,126
    ,126
    ,126
    ,126
    ,126
    ,126
    ,126
    ,126
    ,126
    ,126
    ,126
    ,126
    ,126
    ,126
    ,126
    ,126
    ,126
    ,126
    ,126
    ,126
    ,126
    ,127
    ,126
    ,126
    ,127
    ,126
    ,126
    ,127
    ,126
    ,126
    ,127
    ,127
    ,126
    ,127
};
int kick_length=4878;

const char tick_table[] PROGMEM = 

{
  128
    ,133
    ,91
    ,180
    ,115
    ,97
    ,159
    ,146
    ,93
    ,108
    ,225
    ,28
    ,159
    ,156
    ,100
    ,146
    ,84
    ,207
    ,52
    ,128
    ,164
    ,165
    ,10
    ,252
    ,83
    ,84
    ,141
    ,195
    ,71
    ,88
    ,245
    ,7
    ,198
    ,106
    ,139
    ,116
    ,153
    ,111
    ,94
    ,166
    ,80
    ,98
    ,175
    ,135
    ,130
    ,46
    ,245
    ,57
    ,145
    ,152
    ,96
    ,117
    ,170
    ,125
    ,87
    ,173
    ,109
    ,134
    ,105
    ,150
    ,142
    ,106
    ,102
    ,224
    ,12
    ,168
    ,145
    ,109
    ,149
    ,112
    ,146
    ,138
    ,57
    ,177
    ,167
    ,71
    ,135
    ,178
    ,91
    ,91
    ,210
    ,103
    ,82
    ,198
    ,95
    ,112
    ,139
    ,156
    ,111
    ,89
    ,203
    ,95
    ,108
    ,162
    ,103
    ,139
    ,141
    ,98
    ,143
    ,125
    ,136
    ,115
    ,113
    ,207
    ,28
    ,164
    ,160
    ,92
    ,130
    ,108
    ,187
    ,55
    ,143
    ,143
    ,162
    ,39
    ,221
    ,98
    ,87
    ,170
    ,164
    ,68
    ,137
    ,178
    ,90
    ,127
    ,107
    ,193
    ,87
    ,107
    ,180
    ,120
    ,94
    ,143
    ,107
    ,197
    ,54
    ,162
    ,127
    ,90
    ,211
    ,72
    ,119
    ,184
    ,100
    ,112
    ,161
    ,121
    ,101
    ,162
    ,105
    ,150
    ,86
    ,166
    ,127
    ,111
    ,136
    ,120
    ,112
    ,163
    ,124
    ,53
    ,219
    ,91
    ,137
    ,113
    ,136
    ,146
    ,130
    ,85
    ,156
    ,154
    ,87
    ,126
    ,162
    ,127
    ,98
    ,119
    ,191
    ,93
    ,100
    ,216
    ,67
    ,118
    ,159
    ,147
    ,62
    ,191
    ,111
    ,104
    ,160
    ,122
    ,102
    ,123
    ,182
    ,38
    ,196
    ,63
    ,210
    ,73
    ,122
    ,136
    ,140
    ,135
    ,98
    ,170
    ,69
    ,197
    ,81
    ,152
    ,106
    ,142
    ,135
    ,113
    ,134
    ,152
    ,65
    ,191
    ,110
    ,99
    ,154
    ,135
    ,129
    ,82
    ,196
    ,97
    ,107
    ,171
    ,109
    ,110
    ,163
    ,108
    ,131
    ,103
    ,176
    ,98
    ,139
    ,102
    ,152
    ,154
    ,57
    ,160
    ,153
    ,98
    ,138
    ,138
    ,95
    ,153
    ,144
    ,108
    ,103
    ,179
    ,97
    ,120
    ,122
    ,174
    ,92
    ,111
    ,177
    ,96
    ,118
    ,167
    ,114
    ,118
    ,135
    ,138
    ,115
    ,134
    ,140
    ,98
    ,138
    ,159
    ,74
    ,158
    ,120
    ,141
    ,113
    ,121
    ,158
    ,104
    ,101
    ,183
    ,115
    ,86
    ,191
    ,89
    ,130
    ,119
    ,189
    ,54
    ,166
    ,146
    ,89
    ,136
    ,149
    ,106
    ,102
    ,159
    ,130
    ,98
    ,142
    ,142
    ,121
    ,111
    ,158
    ,127
    ,79
    ,201
    ,82
    ,116
    ,175
    ,95
    ,127
    ,141
    ,127
    ,133
    ,100
    ,163
    ,131
    ,76
    ,175
    ,118
    ,115
    ,133
    ,146
    ,108
    ,132
    ,123
    ,162
    ,90
    ,135
    ,166
    ,66
    ,184
    ,108
    ,120
    ,141
    ,116
    ,154
    ,118
    ,94
    ,202
    ,78
    ,144
    ,163
    ,92
    ,128
    ,153
    ,118
    ,122
    ,116
    ,150
    ,128
    ,100
    ,149
    ,149
    ,77
    ,171
    ,121
    ,100
    ,141
    ,150
    ,104
    ,124
    ,158
    ,103
    ,133
    ,118
    ,158
    ,112
    ,120
    ,124
    ,159
    ,97
    ,122
    ,156
    ,114
    ,117
    ,150
    ,115
    ,112
    ,157
    ,118
    ,109
    ,134
    ,152
    ,101
    ,129
    ,164
    ,81
    ,149
    ,146
    ,122
    ,103
    ,154
    ,146
    ,77
    ,166
    ,138
    ,94
    ,136
    ,160
    ,91
    ,142
    ,139
    ,104
    ,141
    ,119
    ,152
    ,96
    ,128
    ,169
    ,56
    ,173
    ,131
    ,106
    ,130
    ,154
    ,113
    ,114
    ,144
    ,125
    ,137
    ,115
    ,130
    ,127
    ,140
    ,116
    ,123
    ,133
    ,145
    ,101
    ,157
    ,98
    ,143
    ,126
    ,146
    ,97
    ,151
    ,111
    ,148
    ,111
    ,127
    ,155
    ,88
    ,162
    ,109
    ,126
    ,128
    ,153
    ,89
    ,142
    ,142
    ,112
    ,138
    ,108
    ,158
    ,114
    ,128
    ,134
    ,111
    ,132
    ,153
    ,93
    ,150
    ,129
    ,119
    ,125
    ,137
    ,143
    ,83
    ,178
    ,99
    ,127
    ,140
    ,118
    ,124
    ,162
    ,73
    ,167
    ,125
    ,114
    ,135
    ,136
    ,114
    ,141
    ,123
    ,110
    ,159
    ,112
    ,113
    ,142
    ,141
    ,107
    ,134
    ,122
    ,155
    ,96
    ,149
    ,124
    ,113
    ,136
    ,151
    ,95
    ,147
    ,130
    ,117
    ,133
    ,145
    ,103
    ,130
    ,152
    ,102
    ,138
    ,124
    ,132
    ,130
    ,123
    ,122
    ,145
    ,116
    ,125
    ,135
    ,124
    ,137
    ,120
    ,121
    ,163
    ,92
    ,136
    ,153
    ,95
    ,147
    ,131
    ,114
    ,124
    ,153
    ,102
    ,139
    ,132
    ,123
    ,118
    ,150
    ,126
    ,105
    ,149
    ,128
    ,125
    ,108
    ,169
    ,94
    ,141
    ,133
    ,121
    ,117
    ,149
    ,125
    ,107
    ,142
    ,133
    ,122
    ,111
    ,164
    ,108
    ,116
    ,156
    ,105
    ,130
    ,134
    ,125
    ,133
    ,106
    ,168
    ,105
    ,125
    ,142
    ,132
    ,108
    ,136
    ,148
    ,97
    ,138
    ,140
    ,118
    ,129
    ,136
    ,113
    ,142
    ,120
    ,134
    ,122
    ,135
    ,123
    ,135
    ,107
    ,152
    ,119
    ,112
    ,137
    ,143
    ,105
    ,131
    ,148
    ,92
    ,164
    ,108
    ,138
    ,110
    ,151
    ,122
    ,104
    ,157
    ,119
    ,117
    ,133
    ,136
    ,130
    ,101
    ,160
    ,112
    ,118
    ,138
    ,125
    ,135
    ,118
    ,134
    ,131
    ,122
    ,120
    ,151
    ,110
    ,130
    ,133
    ,126
    ,116
    ,143
    ,129
    ,105
    ,147
    ,127
    ,125
    ,117
    ,137
    ,137
    ,113
    ,126
    ,145
    ,119
    ,117
    ,147
    ,117
    ,127
    ,137
    ,112
    ,137
    ,136
    ,110
    ,141
    ,121
    ,133
    ,123
    ,119
    ,153
    ,111
    ,116
    ,148
    ,129
    ,107
    ,146
    ,131
    ,112
    ,144
    ,124
    ,129
    ,111
    ,160
    ,103
    ,131
    ,126
    ,141
    ,114
    ,125
    ,156
    ,103
    ,129
    ,145
    ,118
    ,123
    ,127
    ,138
    ,125
    ,117
    ,145
    ,102
    ,156
    ,113
    ,129
    ,136
    ,120
    ,124
    ,145
    ,109
    ,137
    ,134
    ,115
    ,137
    ,125
    ,128
    ,131
    ,115
    ,150
    ,111
    ,136
    ,130
    ,113
    ,154
    ,108
    ,129
    ,133
    ,127
    ,123
    ,143
    ,113
    ,132
    ,130
    ,126
    ,132
    ,124
    ,121
    ,143
    ,120
    ,126
    ,131
    ,119
    ,148
    ,108
    ,144
    ,117
    ,129
    ,137
    ,123
    ,119
    ,136
    ,136
    ,117
    ,129
    ,127
    ,141
    ,111
    ,141
    ,123
    ,119
    ,146
    ,117
    ,130
    ,130
    ,130
    ,121
    ,128
    ,140
    ,118
    ,126
    ,137
    ,128
    ,115
    ,144
    ,121
    ,130
    ,117
    ,147
    ,120
    ,125
    ,130
    ,130
    ,136
    ,116
    ,129
    ,131
    ,133
    ,116
    ,142
    ,113
    ,134
    ,138
    ,116
    ,125
    ,141
    ,125
    ,115
    ,145
    ,120
    ,131
    ,121
    ,135
    ,130
    ,116
    ,132
    ,136
    ,118
    ,126
    ,135
    ,118
    ,145
    ,112
    ,134
    ,129
    ,127
    ,130
    ,119
    ,138
    ,127
    ,119
    ,131
    ,133
    ,128
    ,116
    ,143
    ,125
    ,119
    ,139
    ,126
    ,119
    ,133
    ,137
    ,114
    ,128
    ,141
    ,122
    ,117
    ,143
    ,122
    ,124
    ,129
    ,137
    ,119
    ,124
    ,137
    ,129
    ,116
    ,133
    ,137
    ,116
    ,130
    ,128
    ,140
    ,107
    ,140
    ,133
    ,117
    ,128
    ,143
    ,116
    ,132
    ,125
    ,132
    ,129
    ,122
    ,137
    ,119
    ,134
    ,127
    ,127
    ,122
    ,144
    ,116
    ,127
    ,137
    ,119
    ,132
    ,128
    ,130
    ,125
    ,125
    ,140
    ,112
    ,131
    ,138
    ,124
    ,115
    ,147
    ,117
    ,128
    ,125
    ,142
    ,115
    ,124
    ,144
    ,117
    ,123
    ,137
    ,131
    ,117
    ,136
    ,121
    ,141
    ,115
    ,129
    ,141
    ,117
    ,125
    ,141
    ,117
    ,126
    ,135
    ,130
    ,117
    ,133
    ,133
    ,121
    ,127
    ,136
    ,121
    ,123
    ,142
    ,117
    ,129
    ,127
    ,135
    ,117
    ,132
    ,135
    ,109
    ,137
    ,132
    ,119
    ,131
    ,132
    ,123
    ,122
    ,137
    ,123
    ,120
    ,134
    ,132
    ,117
    ,134
    ,128
    ,129
    ,120
    ,135
    ,131
    ,114
    ,134
    ,132
    ,125
    ,120
    ,143
    ,114
    ,137
    ,119
    ,139
    ,116
    ,140
    ,127
    ,121
    ,134
    ,122
    ,144
    ,113
    ,135
    ,130
    ,125
    ,128
    ,132
    ,124
    ,130
    ,128
    ,129
    ,127
    ,128
    ,129
    ,129
    ,130
    ,127
    ,131
    ,125
    ,130
    ,129
    ,128
    ,128
    ,129
    ,126
    ,124
    ,138
    ,123
    ,123
    ,137
    ,126
    ,121
    ,132
    ,126
    ,128
    ,135
    ,118
    ,135
    ,120
    ,133
    ,131
    ,121
    ,134
    ,128
    ,126
    ,131
    ,127
    ,128
    ,127
    ,130
    ,127
    ,127
    ,128
    ,127
    ,135
    ,117
    ,134
    ,128
    ,127
    ,131
    ,123
    ,130
    ,132
    ,121
    ,135
    ,120
    ,137
    ,123
    ,128
    ,123
    ,137
    ,123
    ,125
    ,140
    ,113
    ,140
    ,120
    ,134
    ,120
    ,133
    ,131
    ,121
    ,129
    ,135
    ,122
    ,126
    ,136
    ,122
    ,132
    ,125
    ,130
    ,128
    ,128
    ,124
    ,134
    ,127
    ,121
    ,132
    ,132
    ,122
    ,128
    ,134
    ,125
    ,124
    ,136
    ,122
    ,126
    ,135
    ,121
    ,129
    ,125
    ,136
    ,121
    ,126
    ,132
    ,130
    ,118
    ,139
    ,125
    ,123
    ,135
    ,128
    ,122
    ,130
    ,132
    ,119
    ,132
    ,129
    ,123
    ,130
    ,134
    ,123
    ,127
    ,132
    ,132
    ,119
    ,131
    ,133
    ,124
    ,124
    ,139
    ,120
    ,127
    ,134
    ,124
    ,128
    ,126
    ,137
    ,118
    ,129
    ,136
    ,120
    ,131
    ,124
    ,138
    ,119
    ,128
    ,133
    ,126
    ,126
    ,131
    ,130
    ,123
    ,132
    ,127
    ,128
    ,130
    ,124
    ,127
    ,134
    ,122
    ,130
    ,126
    ,126
    ,136
    ,119
    ,130
    ,133
    ,123
    ,129
    ,130
    ,125
    ,128
    ,128
    ,127
    ,126
    ,127
    ,134
    ,117
    ,138
    ,121
    ,130
    ,125
    ,131
    ,129
    ,126
    ,125
    ,133
    ,126
    ,124
    ,130
    ,132
    ,121
    ,132
    ,131
    ,123
    ,128
    ,130
    ,131
    ,118
    ,137
    ,123
    ,128
    ,128
    ,133
    ,121
    ,129
    ,131
    ,127
    ,124
    ,133
    ,125
    ,128
    ,129
    ,128
    ,128
    ,126
    ,133
    ,126
    ,124
    ,132
    ,129
    ,122
    ,130
    ,133
    ,122
    ,130
    ,132
    ,125
    ,126
    ,133
    ,128
    ,120
    ,136
    ,126
    ,124
    ,131
    ,130
    ,122
    ,132
    ,129
    ,125
    ,130
    ,126
    ,131
    ,125
    ,129
    ,128
    ,130
    ,124
    ,133
    ,127
    ,127
    ,131
    ,123
    ,132
    ,125
    ,134
    ,124
    ,127
    ,130
    ,127
    ,126
    ,131
    ,127
    ,125
    ,131
    ,127
    ,128
    ,126
    ,131
    ,130
    ,124
    ,129
    ,129
    ,130
    ,121
    ,135
    ,124
    ,128
    ,128
    ,128
    ,126
    ,130
    ,132
    ,123
    ,129
    ,132
    ,123
    ,129
    ,130
    ,125
    ,133
    ,122
    ,134
    ,124
    ,128
    ,128
    ,133
    ,121
    ,131
    ,130
    ,122
    ,134
    ,127
    ,126
    ,131
    ,126
    ,129
    ,125
    ,131
    ,128
    ,125
    ,129
    ,132
    ,124
    ,128
    ,131
    ,125
    ,129
    ,127
    ,129
    ,127
    ,127
    ,133
    ,124
    ,126
    ,134
    ,124
    ,128
    ,131
    ,126
    ,128
    ,131
    ,125
    ,130
    ,125
    ,133
    ,125
    ,124
    ,134
    ,124
    ,126
    ,133
    ,123
    ,128
    ,130
    ,127
    ,128
    ,130
    ,124
    ,131
    ,129
    ,125
    ,131
    ,128
    ,128
    ,130
    ,127
    ,129
    ,129
    ,126
    ,131
    ,125
    ,130
    ,130
    ,123
    ,131
    ,128
    ,128
    ,126
    ,129
    ,131
    ,123
    ,130
    ,129
    ,126
    ,128
    ,131
    ,125
    ,129
    ,127
    ,130
    ,127
    ,126
    ,130
    ,129
    ,126
    ,130
    ,127
    ,126
    ,132
    ,125
    ,126
    ,132
    ,128
    ,125
    ,132
    ,126
    ,129
    ,126
    ,131
    ,128
    ,126
    ,129
    ,130
    ,124
    ,129
    ,130
    ,125
    ,129
    ,130
    ,126
    ,129
    ,130
    ,128
    ,127
    ,128
    ,131
    ,125
    ,129
    ,128
    ,132
    ,123
    ,131
    ,129
    ,127
    ,129
    ,130
    ,126
    ,127
    ,131
    ,129
    ,124
    ,132
    ,129
    ,126
    ,130
    ,128
    ,128
    ,127
    ,131
    ,126
    ,127
    ,131
    ,128
    ,126
    ,130
    ,127
    ,131
    ,126
    ,128
    ,128
    ,129
    ,128
    ,129
    ,128
    ,130
    ,127
    ,129
    ,127
    ,128
    ,129
    ,126
    ,129
    ,128
    ,128
    ,127
    ,131
    ,128
    ,125
    ,132
    ,127
    ,126
    ,128
    ,132
    ,123
    ,129
    ,130
    ,125
    ,128
    ,130
    ,127
    ,126
    ,129
    ,130
    ,125
    ,128
    ,131
    ,125
    ,127
    ,131
    ,127
    ,126
    ,131
    ,127
    ,128
    ,129
    ,129
    ,127
    ,127
    ,130
    ,127
    ,126
    ,130
    ,126
    ,129
    ,128
    ,128
    ,129
    ,127
    ,130
    ,127
    ,126
    ,130
    ,127
    ,129
    ,126
    ,129
    ,127
    ,127
    ,129
    ,128
    ,126
    ,129
    ,130
    ,125
    ,129
    ,130
    ,126
    ,128
    ,130
    ,127
    ,128
    ,128
    ,128
    ,128
    ,126
    ,130
    ,127
    ,126
    ,132
    ,126
    ,128
    ,126
    ,132
    ,125
    ,127
    ,131
    ,126
    ,128
    ,129
    ,129
    ,125
    ,131
    ,128
    ,126
    ,129
    ,128
    ,126
    ,128
    ,129
    ,127
    ,127
    ,129
    ,129
    ,125
    ,128
    ,128
    ,130
    ,126
    ,129
    ,130
    ,127
    ,129
    ,128
    ,129
    ,125
    ,130
    ,128
    ,125
    ,131
    ,126
    ,127
    ,129
    ,130
    ,125
    ,131
    ,127
    ,128
    ,127
    ,129
    ,128
    ,127
    ,128
    ,129
    ,129
    ,126
    ,129
    ,126
    ,130
    ,127
    ,129
    ,126
    ,129
    ,129
    ,125
    ,130
    ,129
    ,127
    ,127
    ,130
    ,127
    ,126
    ,131
    ,127
    ,127
    ,127
    ,129
    ,126
    ,128
    ,128
    ,127
    ,129
    ,127
    ,129
    ,128
    ,128
    ,127
    ,129
    ,127
    ,128
    ,129
    ,127
    ,127
    ,129
    ,129
    ,127
    ,129
    ,128
    ,129
    ,126
    ,129
    ,128
    ,126
    ,128
    ,128
    ,126
    ,129
    ,129
    ,127
    ,128
    ,129
    ,128
    ,128
    ,129
    ,128
    ,128
    ,130
    ,126
    ,128
    ,130
    ,127
    ,128
    ,129
    ,129
    ,125
    ,130
    ,128
    ,128
    ,128
    ,129
    ,129
    ,127
    ,129
    ,128
    ,128
    ,128
    ,127
    ,128
    ,127
    ,128
    ,128
    ,129
    ,127
    ,129
    ,128
    ,127
    ,128
    ,129
    ,127
    ,128
    ,129
    ,128
    ,128
    ,128
    ,127
    ,128
    ,127
    ,128
    ,129
    ,127
    ,128
    ,128
    ,128
    ,126
    ,129
    ,128
    ,128
    ,129
    ,128
    ,128
    ,128
    ,126
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,129
    ,127
    ,129
    ,128
    ,127
    ,128
    ,128
    ,127
    ,128
    ,128
    ,128
    ,128
    ,129
    ,127
    ,128
    ,128
    ,128
    ,128
    ,128
    ,130
    ,128
    ,127
    ,129
    ,129
    ,126
    ,127
    ,128
    ,127
    ,128
    ,128
    ,128
    ,127
    ,127
    ,128
    ,126
    ,129
    ,128
    ,127
    ,127
    ,130
    ,127
    ,128
    ,129
    ,127
    ,127
    ,129
    ,129
    ,127
    ,130
    ,127
    ,127
    ,128
    ,129
    ,127
    ,129
    ,128
    ,128
    ,128
    ,128
    ,129
    ,127
    ,128
    ,128
    ,128
    ,128
    ,128
    ,129
    ,128
    ,128
    ,128
    ,128
    ,128
    ,129
    ,128
    ,127
    ,128
    ,128
    ,127
    ,127
    ,129
    ,128
    ,127
    ,128
    ,128
    ,128
    ,128
    ,129
    ,127
    ,128
    ,129
    ,127
    ,128
    ,128
    ,129
    ,128
    ,128
    ,129
    ,127
    ,128
    ,128
    ,128
    ,128
    ,129
    ,128
    ,127
    ,129
    ,129
    ,127
    ,128
    ,128
    ,128
    ,127
    ,128
    ,129
    ,127
    ,128
    ,129
    ,127
    ,127
    ,129
    ,128
    ,127
    ,128
    ,128
    ,127
    ,128
    ,129
    ,128
    ,128
    ,129
    ,128
    ,128
    ,129
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,129
    ,128
    ,128
    ,128
    ,127
    ,129
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,129
    ,128
    ,128
    ,128
    ,128
    ,128
    ,127
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,127
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,127
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,127
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,127
    ,128

};
int tick_length=1906;

const char snare_table[] PROGMEM= //clap
{ 
  127
    ,123
    ,95
    ,74
    ,86
    ,160
    ,127
    ,73
    ,102
    ,151
    ,141
    ,186
    ,186
    ,126
    ,170
    ,180
    ,187
    ,181
    ,132
    ,188
    ,155
    ,113
    ,191
    ,184
    ,226
    ,165
    ,90
    ,117
    ,109
    ,97
    ,189
    ,199
    ,157
    ,124
    ,116
    ,141
    ,87
    ,15
    ,106
    ,98
    ,11
    ,32
    ,34
    ,17
    ,22
    ,27
    ,46
    ,39
    ,20
    ,31
    ,74
    ,64
    ,44
    ,57
    ,65
    ,72
    ,80
    ,99
    ,92
    ,105
    ,109
    ,117
    ,129
    ,120
    ,129
    ,144
    ,121
    ,136
    ,161
    ,165
    ,147
    ,194
    ,203
    ,178
    ,147
    ,183
    ,202
    ,170
    ,188
    ,211
    ,190
    ,195
    ,220
    ,205
    ,217
    ,240
    ,221
    ,187
    ,210
    ,220
    ,215
    ,197
    ,197
    ,204
    ,189
    ,184
    ,187
    ,186
    ,172
    ,158
    ,162
    ,158
    ,149
    ,145
    ,139
    ,125
    ,124
    ,122
    ,112
    ,114
    ,114
    ,90
    ,63
    ,80
    ,79
    ,72
    ,76
    ,52
    ,36
    ,36
    ,54
    ,56
    ,31
    ,33
    ,55
    ,53
    ,26
    ,34
    ,55
    ,43
    ,50
    ,70
    ,53
    ,41
    ,59
    ,68
    ,64
    ,77
    ,77
    ,56
    ,62
    ,75
    ,90
    ,69
    ,65
    ,89
    ,73
    ,67
    ,80
    ,91
    ,87
    ,84
    ,96
    ,104
    ,103
    ,108
    ,115
    ,125
    ,121
    ,127
    ,142
    ,138
    ,147
    ,159
    ,161
    ,167
    ,174
    ,178
    ,185
    ,188
    ,190
    ,197
    ,203
    ,202
    ,201
    ,199
    ,206
    ,215
    ,213
    ,214
    ,220
    ,224
    ,225
    ,226
    ,224
    ,232
    ,234
    ,231
    ,231
    ,233
    ,232
    ,229
    ,230
    ,229
    ,225
    ,223
    ,220
    ,218
    ,209
    ,206
    ,200
    ,187
    ,187
    ,205
    ,172
    ,160
    ,200
    ,190
    ,139
    ,159
    ,170
    ,143
    ,159
    ,123
    ,148
    ,164
    ,111
    ,131
    ,155
    ,161
    ,130
    ,122
    ,140
    ,127
    ,135
    ,130
    ,123
    ,116
    ,120
    ,112
    ,107
    ,101
    ,100
    ,97
    ,89
    ,83
    ,80
    ,78
    ,70
    ,69
    ,66
    ,61
    ,59
    ,57
    ,54
    ,55
    ,46
    ,39
    ,33
    ,41
    ,53
    ,36
    ,30
    ,39
    ,43
    ,52
    ,61
    ,36
    ,46
    ,59
    ,48
    ,74
    ,61
    ,56
    ,61
    ,63
    ,72
    ,79
    ,90
    ,79
    ,43
    ,43
    ,51
    ,52
    ,106
    ,108
    ,66
    ,67
    ,75
    ,94
    ,64
    ,51
    ,85
    ,88
    ,79
    ,81
    ,81
    ,83
    ,90
    ,109
    ,122
    ,113
    ,109
    ,132
    ,155
    ,143
    ,137
    ,144
    ,174
    ,172
    ,156
    ,166
    ,193
    ,188
    ,179
    ,198
    ,186
    ,191
    ,202
    ,201
    ,207
    ,209
    ,208
    ,209
    ,222
    ,222
    ,217
    ,204
    ,213
    ,226
    ,210
    ,205
    ,217
    ,225
    ,215
    ,207
    ,221
    ,221
    ,210
    ,209
    ,221
    ,211
    ,204
    ,216
    ,189
    ,199
    ,196
    ,171
    ,189
    ,187
    ,157
    ,154
    ,165
    ,152
    ,162
    ,157
    ,164
    ,167
    ,141
    ,145
    ,152
    ,127
    ,136
    ,136
    ,93
    ,103
    ,117
    ,97
    ,95
    ,87
    ,65
    ,70
    ,92
    ,74
    ,56
    ,65
    ,56
    ,55
    ,53
    ,68
    ,54
    ,50
    ,59
    ,52
    ,48
    ,59
    ,59
    ,55
    ,58
    ,64
    ,44
    ,50
    ,65
    ,68
    ,44
    ,40
    ,59
    ,41
    ,44
    ,68
    ,66
    ,51
    ,53
    ,55
    ,64
    ,65
    ,66
    ,59
    ,77
    ,69
    ,78
    ,72
    ,69
    ,84
    ,68
    ,74
    ,95
    ,95
    ,109
    ,100
    ,86
    ,99
    ,122
    ,112
    ,110
    ,132
    ,121
    ,120
    ,145
    ,149
    ,150
    ,148
    ,157
    ,165
    ,160
    ,192
    ,186
    ,176
    ,202
    ,208
    ,180
    ,192
    ,216
    ,201
    ,193
    ,200
    ,203
    ,206
    ,203
    ,200
    ,199
    ,221
    ,227
    ,185
    ,198
    ,226
    ,219
    ,203
    ,197
    ,222
    ,209
    ,213
    ,197
    ,212
    ,216
    ,178
    ,201
    ,223
    ,192
    ,184
    ,187
    ,200
    ,196
    ,210
    ,195
    ,186
    ,200
    ,186
    ,181
    ,182
    ,170
    ,145
    ,169
    ,159
    ,145
    ,168
    ,162
    ,138
    ,129
    ,136
    ,134
    ,127
    ,150
    ,135
    ,101
    ,125
    ,125
    ,86
    ,91
    ,87
    ,74
    ,55
    ,71
    ,95
    ,71
    ,45
    ,79
    ,85
    ,67
    ,58
    ,68
    ,81
    ,64
    ,51
    ,55
    ,71
    ,61
    ,37
    ,36
    ,55
    ,58
    ,49
    ,54
    ,45
    ,44
    ,53
    ,36
    ,41
    ,57
    ,44
    ,44
    ,62
    ,62
    ,58
    ,43
    ,60
    ,75
    ,73
    ,60
    ,79
    ,83
    ,88
    ,104
    ,94
    ,81
    ,102
    ,108
    ,73
    ,100
    ,116
    ,86
    ,97
    ,112
    ,126
    ,130
    ,131
    ,147
    ,136
    ,138
    ,154
    ,142
    ,144
    ,160
    ,146
    ,160
    ,191
    ,177
    ,151
    ,179
    ,187
    ,180
    ,195
    ,203
    ,169
    ,182
    ,221
    ,211
    ,179
    ,190
    ,209
    ,186
    ,196
    ,196
    ,200
    ,198
    ,184
    ,190
    ,213
    ,184
    ,193
    ,224
    ,210
    ,197
    ,196
    ,197
    ,187
    ,178
    ,202
    ,197
    ,182
    ,194
    ,182
    ,184
    ,191
    ,177
    ,162
    ,180
    ,186
    ,168
    ,177
    ,159
    ,143
    ,177
    ,155
    ,142
    ,146
    ,128
    ,109
    ,127
    ,118
    ,120
    ,116
    ,85
    ,127
    ,125
    ,66
    ,67
    ,98
    ,66
    ,29
    ,45
    ,68
    ,55
    ,59
    ,79
    ,78
    ,37
    ,66
    ,96
    ,50
    ,30
    ,57
    ,59
    ,34
    ,45
    ,35
    ,46
    ,57
    ,53
    ,57
    ,71
    ,57
    ,55
    ,73
    ,50
    ,51
    ,51
    ,53
    ,65
    ,54
    ,51
    ,46
    ,61
    ,82
    ,57
    ,52
    ,58
    ,79
    ,114
    ,74
    ,51
    ,105
    ,114
    ,64
    ,86
    ,121
    ,102
    ,82
    ,100
    ,129
    ,108
    ,84
    ,132
    ,138
    ,112
    ,125
    ,135
    ,156
    ,158
    ,133
    ,141
    ,169
    ,163
    ,143
    ,148
    ,187
    ,191
    ,132
    ,164
    ,212
    ,156
    ,160
    ,167
    ,180
    ,181
    ,223
    ,210
    ,179
    ,235
    ,204
    ,168
    ,211
    ,190
    ,165
    ,221
    ,220
    ,185
    ,195
    ,219
    ,192
    ,187
    ,220
    ,195
    ,191
    ,226
    ,194
    ,203
    ,219
    ,210
    ,189
    ,167
    ,179
    ,183
    ,192
    ,208
    ,191
    ,140
    ,179
    ,215
    ,185
    ,160
    ,171
    ,206
    ,144
    ,135
    ,193
    ,195
    ,130
    ,94
    ,142
    ,153
    ,151
    ,121
    ,125
    ,142
    ,112
    ,111
    ,115
    ,126
    ,110
    ,114
    ,136
    ,104
    ,111
    ,106
    ,78
    ,76
    ,102
    ,88
    ,72
    ,93
    ,105
    ,79
    ,65
    ,74
    ,84
    ,70
    ,52
    ,81
    ,74
    ,37
    ,55
    ,92
    ,66
    ,47
    ,74
    ,71
    ,54
    ,64
    ,54
    ,66
    ,96
    ,59
    ,39
    ,78
    ,84
    ,48
    ,68
    ,93
    ,81
    ,100
    ,110
    ,73
    ,67
    ,115
    ,105
    ,78
    ,105
    ,122
    ,92
    ,98
    ,148
    ,131
    ,111
    ,130
    ,137
    ,139
    ,124
    ,151
    ,189
    ,129
    ,126
    ,174
    ,169
    ,141
    ,172
    ,194
    ,157
    ,187
    ,175
    ,158
    ,172
    ,184
    ,172
    ,168
    ,178
    ,170
    ,193
    ,215
    ,191
    ,184
    ,161
    ,170
    ,207
    ,188
    ,172
    ,169
    ,186
    ,202
    ,170
    ,156
    ,197
    ,176
    ,141
    ,178
    ,194
    ,155
    ,154
    ,163
    ,156
    ,152
    ,160
    ,187
    ,143
    ,136
    ,169
    ,162
    ,137
    ,133
    ,139
    ,141
    ,141
    ,144
    ,133
    ,132
    ,160
    ,128
    ,133
    ,140
    ,120
    ,129
    ,139
    ,126
    ,112
    ,136
    ,111
    ,98
    ,126
    ,114
    ,103
    ,99
    ,116
    ,111
    ,87
    ,114
    ,123
    ,79
    ,68
    ,110
    ,99
    ,61
    ,105
    ,94
    ,59
    ,64
    ,91
    ,87
    ,59
    ,75
    ,72
    ,59
    ,88
    ,102
    ,66
    ,61
    ,65
    ,102
    ,99
    ,62
    ,57
    ,79
    ,111
    ,85
    ,61
    ,77
    ,84
    ,87
    ,80
    ,106
    ,87
    ,80
    ,116
    ,88
    ,98
    ,127
    ,102
    ,85
    ,96
    ,109
    ,124
    ,111
    ,110
    ,115
    ,128
    ,110
    ,111
    ,147
    ,111
    ,87
    ,132
    ,132
    ,146
    ,145
    ,147
    ,135
    ,142
    ,147
    ,133
    ,159
    ,152
    ,140
    ,142
    ,179
    ,158
    ,160
    ,168
    ,157
    ,139
    ,147
    ,165
    ,194
    ,193
    ,161
    ,147
    ,162
    ,172
    ,167
    ,169
    ,175
    ,152
    ,154
    ,180
    ,175
    ,179
    ,165
    ,174
    ,159
    ,175
    ,175
    ,140
    ,163
    ,175
    ,143
    ,147
    ,190
    ,160
    ,130
    ,167
    ,166
    ,116
    ,132
    ,162
    ,141
    ,126
    ,120
    ,149
    ,137
    ,116
    ,129
    ,141
    ,144
    ,114
    ,115
    ,129
    ,118
    ,113
    ,126
    ,122
    ,79
    ,78
    ,108
    ,145
    ,92
    ,85
    ,143
    ,112
    ,73
    ,96
    ,90
    ,74
    ,121
    ,114
    ,78
    ,97
    ,124
    ,105
    ,96
    ,107
    ,100
    ,98
    ,109
    ,122
    ,108
    ,86
    ,106
    ,131
    ,99
    ,76
    ,103
    ,113
    ,104
    ,99
    ,109
    ,101
    ,101
    ,107
    ,113
    ,115
    ,114
    ,104
    ,121
    ,129
    ,109
    ,97
    ,128
    ,119
    ,117
    ,122
    ,121
    ,138
    ,134
    ,132
    ,116
    ,132
    ,131
    ,134
    ,149
    ,128
    ,150
    ,174
    ,124
    ,121
    ,144
    ,132
    ,113
    ,142
    ,162
    ,144
    ,134
    ,134
    ,144
    ,167
    ,160
    ,162
    ,139
    ,131
    ,178
    ,155
    ,153
    ,165
    ,144
    ,138
    ,185
    ,165
    ,156
    ,142
    ,131
    ,161
    ,182
    ,167
    ,133
    ,164
    ,170
    ,152
    ,165
    ,174
    ,145
    ,150
    ,148
    ,147
    ,147
    ,182
    ,140
    ,107
    ,145
    ,165
    ,142
    ,130
    ,129
    ,132
    ,165
    ,151
    ,138
    ,104
    ,131
    ,166
    ,150
    ,110
    ,120
    ,146
    ,127
    ,109
    ,131
    ,120
    ,79
    ,132
    ,130
    ,120
    ,101
    ,93
    ,119
    ,103
    ,104
    ,118
    ,126
    ,84
    ,73
    ,128
    ,128
    ,82
    ,97
    ,112
    ,118
    ,82
    ,85
    ,110
    ,70
    ,64
    ,102
    ,109
    ,96
    ,104
    ,99
    ,113
    ,111
    ,72
    ,101
    ,119
    ,81
    ,101
    ,126
    ,102
    ,90
    ,112
    ,92
    ,85
    ,110
    ,106
    ,115
    ,133
    ,130
    ,100
    ,120
    ,118
    ,120
    ,126
    ,131
    ,136
    ,113
    ,115
    ,135
    ,155
    ,131
    ,114
    ,138
    ,139
    ,134
    ,144
    ,129
    ,135
    ,140
    ,145
    ,148
    ,145
    ,143
    ,162
    ,136
    ,118
    ,164
    ,134
    ,136
    ,160
    ,127
    ,142
    ,158
    ,155
    ,139
    ,171
    ,157
    ,116
    ,127
    ,122
    ,153
    ,191
    ,127
    ,104
    ,145
    ,164
    ,164
    ,127
    ,139
    ,167
    ,150
    ,115
    ,142
    ,130
    ,140
    ,154
    ,138
    ,149
    ,146
    ,132
    ,137
    ,141
    ,159
    ,139
    ,133
    ,142
    ,132
    ,131
    ,124
    ,145
    ,135
    ,104
    ,119
    ,146
    ,131
    ,106
    ,129
    ,132
    ,99
    ,136
    ,127
    ,126
    ,142
    ,95
    ,87
    ,130
    ,131
    ,125
    ,82
    ,79
    ,140
    ,124
    ,73
    ,102
    ,161
    ,105
    ,76
    ,121
    ,113
    ,100
    ,89
    ,144
    ,133
    ,75
    ,89
    ,118
    ,79
    ,85
    ,133
    ,107
    ,91
    ,105
    ,102
    ,88
    ,128
    ,117
    ,110
    ,98
    ,112
    ,144
    ,108
    ,97
    ,142
    ,112
    ,118
    ,125
    ,137
    ,114
    ,91
    ,140
    ,133
    ,132
    ,121
    ,130
    ,136
    ,138
    ,148
    ,140
    ,127
    ,157
    ,130
    ,110
    ,170
    ,161
    ,125
    ,144
    ,150
    ,144
    ,141
    ,151
    ,169
    ,169
    ,124
    ,134
    ,166
    ,148
    ,162
    ,154
    ,132
    ,164
    ,185
    ,132
    ,140
    ,162
    ,151
    ,126
    ,136
    ,174
    ,162
    ,130
    ,142
    ,152
    ,145
    ,181
    ,145
    ,125
    ,141
    ,136
    ,161
    ,156
    ,134
    ,129
    ,150
    ,158
    ,114
    ,115
    ,149
    ,141
    ,117
    ,149
    ,137
    ,112
    ,146
    ,148
    ,122
    ,103
    ,138
    ,150
    ,95
    ,117
    ,150
    ,107
    ,110
    ,129
    ,95
    ,102
    ,122
    ,116
    ,121
    ,111
    ,103
    ,103
    ,139
    ,128
    ,90
    ,93
    ,125
    ,141
    ,94
    ,87
    ,105
    ,124
    ,100
    ,97
    ,122
    ,86
    ,129
    ,117
    ,80
    ,106
    ,113
    ,131
    ,116
    ,97
    ,100
    ,112
    ,94
    ,119
    ,126
    ,94
    ,118
    ,119
    ,123
    ,108
    ,120
    ,103
    ,118
    ,137
    ,94
    ,110
    ,123
    ,141
    ,123
    ,100
    ,140
    ,145
    ,123
    ,138
    ,140
    ,135
    ,138
    ,103
    ,137
    ,167
    ,118
    ,130
    ,143
    ,139
    ,148
    ,132
    ,152
    ,151
    ,142
    ,150
    ,140
    ,145
    ,129
    ,146
    ,149
    ,159
    ,174
    ,135
    ,142
    ,164
    ,154
    ,145
    ,153
    ,162
    ,155
    ,138
    ,120
    ,168
    ,169
    ,99
    ,114
    ,161
    ,159
    ,126
    ,126
    ,157
    ,136
    ,113
    ,133
    ,156
    ,157
    ,132
    ,112
    ,140
    ,149
    ,111
    ,152
    ,150
    ,95
    ,125
    ,144
    ,108
    ,121
    ,156
    ,102
    ,101
    ,135
    ,99
    ,97
    ,126
    ,121
    ,117
    ,130
    ,109
    ,103
    ,117
    ,130
    ,103
    ,123
    ,121
    ,74
    ,124
    ,117
    ,98
    ,99
    ,112
    ,101
    ,102
    ,124
    ,113
    ,110
    ,108
    ,127
    ,122
    ,87
    ,112
    ,140
    ,97
    ,105
    ,142
    ,112
    ,94
    ,136
    ,130
    ,124
    ,126
    ,77
    ,125
    ,141
    ,121
    ,133
    ,109
    ,115
    ,173
    ,126
    ,93
    ,149
    ,142
    ,130
    ,116
    ,138
    ,152
    ,128
    ,129
    ,143
    ,132
    ,176
    ,144
    ,102
    ,136
    ,168
    ,144
    ,121
    ,159
    ,140
    ,138
    ,165
    ,140
    ,119
    ,149
    ,181
    ,137
    ,134
    ,164
    ,116
    ,141
    ,164
    ,127
    ,139
    ,160
    ,130
    ,140
    ,160
    ,134
    ,153
    ,140
    ,127
    ,140
    ,146
    ,133
    ,127
    ,155
    ,141
    ,112
    ,158
    ,154
    ,88
    ,126
    ,150
    ,128
    ,114
    ,141
    ,119
    ,103
    ,133
    ,149
    ,108
    ,94
    ,151
    ,150
    ,84
    ,100
    ,158
    ,119
    ,104
    ,123
    ,102
    ,113
    ,126
    ,124
    ,123
    ,108
    ,110
    ,135
    ,114
    ,107
    ,108
    ,116
    ,132
    ,126
    ,101
    ,112
    ,137
    ,101
    ,119
    ,122
    ,121
    ,103
    ,125
    ,136
    ,111
    ,98
    ,123
    ,141
    ,123
    ,110
    ,109
    ,133
    ,130
    ,116
    ,126
    ,142
    ,112
    ,119
    ,141
    ,116
    ,125
    ,129
    ,117
    ,144
    ,150
    ,115
    ,125
    ,145
    ,141
    ,132
    ,123
    ,151
    ,146
    ,117
    ,112
    ,157
    ,147
    ,100
    ,140
    ,149
    ,115
    ,132
    ,167
    ,129
    ,101
    ,142
    ,149
    ,137
    ,138
    ,118
    ,137
    ,146
    ,132
    ,133
    ,143
    ,142
    ,122
    ,136
    ,129
    ,124
    ,154
    ,127
    ,118
    ,145
    ,120
    ,117
    ,149
    ,136
    ,113
    ,141
    ,118
    ,129
    ,152
    ,115
    ,112
    ,143
    ,114
    ,109
    ,150
    ,121
    ,103
    ,127
    ,137
    ,111
    ,133
    ,133
    ,115
    ,121
    ,128
    ,129
    ,107
    ,131
    ,133
    ,105
    ,121
    ,131
    ,127
    ,126
    ,123
    ,118
    ,114
    ,138
    ,118
    ,110
    ,129
    ,131
    ,128
    ,117
    ,117
    ,138
    ,125
    ,118
    ,141
    ,122
    ,107
    ,138
    ,136
    ,112
    ,118
    ,130
    ,133
    ,124
    ,136
    ,124
    ,115
    ,139
    ,153
    ,104
    ,130
    ,146
    ,123
    ,133
    ,135
    ,115
    ,129
    ,150
    ,118
    ,127
    ,143
    ,123
    ,124
    ,137
    ,134
    ,133
    ,128
    ,123
    ,140
    ,139
    ,134
    ,126
    ,128
    ,138
    ,132
    ,134
    ,122
    ,144
    ,143
    ,128
    ,127
    ,135
    ,117
    ,131
    ,151
    ,115
    ,124
    ,150
    ,118
    ,117
    ,154
    ,135
    ,104
    ,124
    ,147
    ,133
    ,108
    ,127
    ,142
    ,120
    ,122
    ,127
    ,131
    ,123
    ,132
    ,131
    ,133
    ,112
    ,125
    ,140
    ,120
    ,120
    ,132
    ,137
    ,124
    ,113
    ,121
    ,144
    ,123
    ,116
    ,126
    ,132
    ,114
    ,126
    ,143
    ,116
    ,111
    ,128
    ,134
    ,130
    ,119
    ,112
    ,143
    ,124
    ,112
    ,135
    ,129
    ,113
    ,132
    ,130
    ,116
    ,139
    ,113
    ,120
    ,143
    ,130
    ,113
    ,123
    ,139
    ,124
    ,110
    ,136
    ,131
    ,120
    ,127
    ,127
    ,135
    ,114
    ,133
    ,134
    ,112
    ,126
    ,143
    ,130
    ,108
    ,124
    ,144
    ,127
    ,113
    ,130
    ,140
    ,120
    ,127
    ,131
    ,134
    ,132
    ,119
    ,135
    ,126
    ,126
    ,135
    ,128
    ,131
    ,124
    ,124
    ,140
    ,131
    ,121
    ,135
    ,126
    ,130
    ,137
    ,119
    ,127
    ,135
    ,127
    ,132
    ,134
    ,122
    ,130
    ,132
    ,129
    ,124
    ,137
    ,132
    ,122
    ,127
    ,133
    ,125
    ,127
    ,139
    ,127
    ,124
    ,137
    ,127
    ,133
    ,131
    ,125
    ,138
    ,130
    ,124
    ,128
    ,138
    ,128
    ,121
    ,137
    ,129
    ,122
    ,138
    ,134
    ,127
    ,121
    ,125
    ,134
    ,130
    ,130
    ,124
    ,125
    ,134
    ,129
    ,126
    ,131
    ,127
    ,125
    ,133
    ,122
    ,128
    ,136
    ,120
    ,123
    ,131
    ,130
    ,125
    ,125
    ,133
    ,120
    ,135
    ,123
    ,121
    ,133
    ,129
    ,123
    ,121
    ,133
    ,130
    ,124
    ,120
    ,136
    ,125
    ,127
    ,126
    ,126
    ,127
    ,133
    ,128
    ,116
    ,129
    ,127
    ,131
    ,129
    ,124
    ,128
    ,125
    ,126
    ,134
    ,126
    ,119
    ,132
    ,129
    ,122
    ,124
    ,135
    ,132
    ,118
    ,125
    ,133
    ,126
    ,120
    ,139
    ,130
    ,117
    ,128
    ,135
    ,124
    ,124
    ,134
    ,127
    ,125
    ,128
    ,126
    ,127
    ,135
    ,126
    ,123
    ,134
    ,129
    ,124
    ,137
    ,133
    ,121
    ,126
    ,135
    ,131
    ,127
    ,126
    ,130
    ,127
    ,126
    ,132
    ,130
    ,124
    ,132
    ,130
    ,128
    ,133
    ,123
    ,129
    ,135
    ,128
    ,125
    ,128
    ,130
    ,128
    ,127
    ,129
    ,126
    ,133
    ,127
    ,125
    ,132
    ,127
    ,129
    ,128
    ,128
    ,128
    ,128
    ,127
    ,122
    ,134
    ,132
    ,119
    ,129
    ,132
    ,124
    ,123
    ,131
    ,132
    ,121
    ,126
    ,131
    ,123
    ,128
    ,129
    ,123
    ,124
    ,131
    ,125
    ,125
    ,127
    ,128
    ,130
    ,124
    ,125
    ,128
    ,126
    ,127
    ,129
    ,128
    ,125
    ,125
    ,128
    ,129
    ,123
    ,126
    ,128
    ,129
    ,129
    ,125
    ,127
    ,126
    ,128
    ,127
    ,128
    ,129
    ,130
    ,127
    ,128
    ,126
    ,129
    ,135
    ,125
    ,128
    ,133
    ,129
    ,127
    ,128
    ,132
    ,127
    ,127
    ,132
    ,126
    ,134
    ,130
    ,125
    ,130
    ,132
    ,129
    ,128
    ,131
    ,133
    ,127
    ,129
    ,132
    ,125
    ,131
    ,135
    ,126
    ,130
    ,129
    ,128
    ,131
    ,131
    ,126
    ,132
    ,130
    ,127
    ,133
    ,127
    ,132
    ,127
    ,128
    ,129
    ,129
    ,127
    ,130
    ,128
    ,129
    ,130
    ,128
    ,127
    ,127
    ,127
    ,129
    ,130
    ,125
    ,130
    ,128
    ,127
    ,128
    ,128
    ,125
    ,126
    ,130
    ,127
    ,124
    ,128
    ,129
    ,124
    ,127
    ,129
    ,129
    ,124
    ,124
    ,131
    ,125
    ,124
    ,128
    ,130
    ,123
    ,122
    ,133
    ,125
    ,123
    ,129
    ,126
    ,123
    ,127
    ,128
    ,124
    ,127
    ,126
    ,124
    ,128
    ,130
    ,126
    ,127
    ,129
    ,121
    ,127
    ,133
    ,126
    ,125
    ,127
    ,128
    ,127
    ,126
    ,130
    ,128
    ,129
    ,129
    ,128
    ,130
    ,129
    ,127
    ,131
    ,129
    ,127
    ,132
    ,128
    ,128
    ,130
    ,128
    ,128
    ,131
    ,128
    ,130
    ,132
    ,126
    ,127
    ,131
    ,130
    ,127
    ,130
    ,132
    ,128
    ,133
    ,131
    ,126
    ,128
    ,131
    ,128
    ,127
    ,129
    ,131
    ,128
    ,130
    ,128
    ,128
    ,131
    ,128
    ,126
    ,131
    ,129
    ,126
    ,130
    ,126
    ,130
    ,129
    ,126
    ,128
    ,130
    ,126
    ,128
    ,129
    ,126
    ,127
    ,128
    ,127
    ,127
    ,128
    ,128
    ,127
    ,127
    ,126
    ,126
    ,127
    ,127
    ,125
    ,128
    ,128
    ,127
    ,128
    ,126
    ,124
    ,129
    ,128
    ,125
    ,129
    ,128
    ,126
    ,126
    ,127
    ,128
    ,127
    ,127
    ,129
    ,130
    ,126
    ,126
    ,131
    ,126
    ,126
    ,128
    ,129
    ,127
    ,128
    ,127
    ,128
    ,128
    ,130
    ,129
    ,127
    ,129
    ,128
    ,127
    ,129
    ,128
    ,128
    ,130
    ,129
    ,129
    ,128
    ,130
    ,129
    ,125
    ,130
    ,130
    ,128
    ,128
    ,129
    ,129
    ,129
    ,128
    ,128
    ,131
    ,130
    ,128
    ,128
    ,130
    ,128
    ,128
    ,129
    ,128
    ,128
    ,130
    ,128
    ,128
    ,129
    ,128
    ,128
    ,128
    ,128
    ,129
    ,127
    ,126
    ,129
    ,128
    ,127
    ,128
    ,128
    ,128
    ,128
    ,127
    ,128
    ,128
    ,128
    ,127
    ,127
    ,127
    ,126
    ,128
    ,128
    ,126
    ,126
    ,128
    ,129
    ,127
    ,126
    ,129
    ,127
    ,125
    ,128
    ,129
    ,126
    ,127
    ,128
    ,127
    ,127
    ,129
    ,128
    ,128
    ,129
    ,127
    ,128
    ,128
    ,128
    ,127
    ,128
    ,127
    ,128
    ,127
    ,127
    ,128
    ,128
    ,128
    ,126
    ,129
    ,129
    ,128
    ,128
    ,127
    ,130
    ,128
    ,126
    ,130
    ,129
    ,126
    ,130
    ,127
    ,127
    ,129
    ,129
    ,127
    ,128
    ,129
    ,129
    ,129
    ,127
    ,128
    ,129
    ,129
    ,128
    ,129
    ,129
    ,129
    ,130
    ,128
    ,129
    ,128
    ,129
    ,129
    ,128
    ,128
    ,128
    ,128
    ,127
    ,129
    ,129
    ,129
    ,128
    ,128
    ,129
    ,128
    ,127
    ,128
    ,128
    ,129
    ,128
    ,127
    ,127
    ,128
    ,129
    ,128
    ,128
    ,128
    ,128
    ,127
    ,128
    ,129
    ,126
    ,127
    ,128
    ,128
    ,127
    ,128
    ,129
    ,128
    ,127
    ,128
    ,129
    ,127
    ,127
    ,127
    ,128
    ,128
    ,128
    ,128
    ,127
    ,127
    ,128
    ,127
    ,127
    ,128
    ,128
    ,127
    ,128
    ,128
    ,128
    ,128
    ,127
    ,126
    ,128
    ,129
    ,126
    ,127
    ,128
    ,128
    ,127
    ,128
    ,129
    ,127
    ,127
    ,128
    ,129
    ,128
    ,128
    ,128
    ,129
    ,128
    ,127
    ,128
    ,128
    ,128
    ,129
    ,129
    ,128
    ,129
    ,128
    ,128
    ,129
    ,128
    ,128
    ,128
    ,128
    ,129
    ,128
    ,129
    ,128
    ,128
    ,129
    ,129
    ,129
    ,128
    ,129
    ,129
    ,127
    ,129
    ,129
    ,128
    ,129
    ,128
    ,129
    ,129
    ,128
    ,128
    ,128
    ,129
    ,129
    ,128
    ,128
    ,128
    ,128
    ,129
    ,127
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,127
    ,128
    ,127
    ,128
    ,128
    ,128
    ,127
    ,128
    ,127
    ,128
    ,128
    ,128
    ,128
    ,127
    ,128
    ,128
    ,127
    ,128
    ,128
    ,128
    ,128
    ,127
    ,128
    ,128
    ,128
    ,127
    ,128
    ,127
    ,128
};

int snare_length= 2640;

const char bass_table[] PROGMEM = 
//button2 tom
{ 
  128
    ,129
    ,131
    ,130
    ,121
    ,121
    ,132
    ,129
    ,117
    ,137
    ,143
    ,119
    ,108
    ,108
    ,132
    ,155
    ,162
    ,127
    ,96
    ,112
    ,119
    ,118
    ,138
    ,165
    ,143
    ,120
    ,112
    ,90
    ,108
    ,149
    ,182
    ,141
    ,133
    ,88
    ,66
    ,120
    ,117
    ,179
    ,189
    ,127
    ,117
    ,94
    ,97
    ,148
    ,126
    ,132
    ,168
    ,104
    ,114
    ,115
    ,142
    ,188
    ,140
    ,187
    ,119
    ,46
    ,121
    ,181
    ,151
    ,136
    ,129
    ,113
    ,73
    ,129
    ,197
    ,122
    ,168
    ,189
    ,74
    ,49
    ,140
    ,163
    ,165
    ,150
    ,122
    ,88
    ,40
    ,143
    ,189
    ,132
    ,138
    ,102
    ,59
    ,100
    ,89
    ,107
    ,166
    ,151
    ,127
    ,74
    ,86
    ,131
    ,121
    ,162
    ,166
    ,145
    ,148
    ,76
    ,88
    ,149
    ,179
    ,156
    ,134
    ,97
    ,176
    ,191
    ,107
    ,150
    ,147
    ,137
    ,107
    ,104
    ,76
    ,109
    ,205
    ,127
    ,78
    ,103
    ,94
    ,118
    ,115
    ,167
    ,202
    ,87
    ,92
    ,97
    ,134
    ,187
    ,131
    ,143
    ,156
    ,119
    ,96
    ,96
    ,150
    ,214
    ,146
    ,107
    ,120
    ,63
    ,53
    ,159
    ,182
    ,161
    ,164
    ,73
    ,57
    ,116
    ,168
    ,162
    ,108
    ,135
    ,123
    ,109
    ,127
    ,126
    ,127
    ,162
    ,138
    ,109
    ,105
    ,124
    ,140
    ,151
    ,154
    ,104
    ,57
    ,75
    ,154
    ,140
    ,172
    ,187
    ,88
    ,99
    ,123
    ,128
    ,184
    ,149
    ,140
    ,153
    ,79
    ,88
    ,142
    ,131
    ,124
    ,148
    ,149
    ,127
    ,56
    ,117
    ,197
    ,145
    ,159
    ,133
    ,79
    ,111
    ,107
    ,80
    ,177
    ,195
    ,164
    ,126
    ,101
    ,102
    ,72
    ,167
    ,178
    ,78
    ,124
    ,119
    ,86
    ,115
    ,127
    ,137
    ,170
    ,136
    ,91
    ,106
    ,129
    ,152
    ,153
    ,152
    ,96
    ,74
    ,129
    ,157
    ,177
    ,195
    ,162
    ,71
    ,62
    ,129
    ,122
    ,184
    ,178
    ,112
    ,79
    ,59
    ,152
    ,157
    ,151
    ,127
    ,143
    ,127
    ,40
    ,83
    ,137
    ,184
    ,161
    ,124
    ,117
    ,78
    ,94
    ,133
    ,172
    ,205
    ,152
    ,62
    ,92
    ,115
    ,154
    ,135
    ,108
    ,145
    ,123
    ,156
    ,115
    ,162
    ,165
    ,99
    ,145
    ,94
    ,118
    ,170
    ,88
    ,149
    ,197
    ,136
    ,96
    ,90
    ,108
    ,178
    ,134
    ,114
    ,116
    ,94
    ,136
    ,124
    ,61
    ,161
    ,204
    ,94
    ,113
    ,109
    ,111
    ,133
    ,128
    ,186
    ,151
    ,107
    ,86
    ,36
    ,191
    ,205
    ,82
    ,128
    ,158
    ,68
    ,113
    ,78
    ,97
    ,189
    ,138
    ,132
    ,111
    ,147
    ,142
    ,102
    ,152
    ,160
    ,108
    ,144
    ,131
    ,143
    ,160
    ,90
    ,113
    ,121
    ,72
    ,142
    ,171
    ,145
    ,133
    ,112
    ,104
    ,104
    ,132
    ,178
    ,118
    ,91
    ,178
    ,113
    ,115
    ,163
    ,155
    ,148
    ,141
    ,119
    ,84
    ,139
    ,154
    ,137
    ,133
    ,131
    ,134
    ,93
    ,92
    ,113
    ,141
    ,116
    ,123
    ,138
    ,125
    ,142
    ,87
    ,120
    ,165
    ,128
    ,134
    ,126
    ,149
    ,187
    ,119
    ,95
    ,115
    ,98
    ,174
    ,108
    ,115
    ,153
    ,121
    ,125
    ,117
    ,101
    ,123
    ,133
    ,95
    ,156
    ,160
    ,127
    ,95
    ,83
    ,108
    ,184
    ,180
    ,114
    ,100
    ,124
    ,106
    ,151
    ,148
    ,177
    ,165
    ,61
    ,87
    ,156
    ,115
    ,108
    ,157
    ,108
    ,160
    ,113
    ,69
    ,128
    ,175
    ,178
    ,121
    ,89
    ,207
    ,139
    ,85
    ,143
    ,97
    ,145
    ,166
    ,92
    ,168
    ,165
    ,90
    ,153
    ,63
    ,134
    ,129
    ,71
    ,179
    ,161
    ,115
    ,157
    ,69
    ,105
    ,127
    ,122
    ,143
    ,120
    ,91
    ,126
    ,95
    ,136
    ,171
    ,84
    ,171
    ,126
    ,141
    ,148
    ,76
    ,96
    ,133
    ,108
    ,158
    ,155
    ,134
    ,133
    ,130
    ,122
    ,144
    ,152
    ,170
    ,79
    ,96
    ,136
    ,84
    ,135
    ,152
    ,204
    ,166
    ,106
    ,47
    ,140
    ,148
    ,151
    ,99
    ,80
    ,140
    ,150
    ,157
    ,122
    ,110
    ,124
    ,159
    ,148
    ,139
    ,131
    ,151
    ,96
    ,80
    ,130
    ,124
    ,142
    ,175
    ,122
    ,145
    ,145
    ,113
    ,60
    ,115
    ,123
    ,146
    ,131
    ,118
    ,148
    ,85
    ,132
    ,171
    ,153
    ,142
    ,50
    ,117
    ,190
    ,80
    ,134
    ,124
    ,49
    ,155
    ,161
    ,101
    ,172
    ,120
    ,103
    ,62
    ,133
    ,188
    ,141
    ,119
    ,94
    ,91
    ,136
    ,193
    ,124
    ,154
    ,161
    ,123
    ,115
    ,115
    ,143
    ,124
    ,123
    ,166
    ,140
    ,118
    ,131
    ,103
    ,133
    ,156
    ,122
    ,138
    ,135
    ,121
    ,139
    ,117
    ,116
    ,129
    ,146
    ,136
    ,111
    ,150
    ,133
    ,117
    ,137
    ,99
    ,129
    ,126
    ,94
    ,134
    ,168
    ,156
    ,84
    ,100
    ,152
    ,118
    ,109
    ,160
    ,153
    ,97
    ,122
    ,113
    ,142
    ,167
    ,113
    ,127
    ,107
    ,151
    ,151
    ,50
    ,137
    ,136
    ,161
    ,179
    ,88
    ,51
    ,122
    ,138
    ,133
    ,169
    ,143
    ,147
    ,74
    ,88
    ,144
    ,130
    ,125
    ,137
    ,135
    ,124
    ,91
    ,131
    ,122
    ,128
    ,180
    ,122
    ,99
    ,121
    ,161
    ,145
    ,113
    ,137
    ,131
    ,100
    ,88
    ,172
    ,178
    ,136
    ,113
    ,95
    ,162
    ,150
    ,147
    ,93
    ,111
    ,136
    ,90
    ,108
    ,201
    ,142
    ,110
    ,164
    ,155
    ,146
    ,55
    ,122
    ,152
    ,127
    ,155
    ,92
    ,98
    ,140
    ,109
    ,119
    ,111
    ,164
    ,103
    ,167
    ,138
    ,82
    ,98
    ,128
    ,103
    ,133
    ,244
    ,83
    ,97
    ,107
    ,117
    ,180
    ,128
    ,71
    ,138
    ,124
    ,78
    ,160
    ,148
    ,113
    ,110
    ,129
    ,139
    ,139
    ,153
    ,111
    ,109
    ,135
    ,152
    ,108
    ,134
    ,202
    ,158
    ,144
    ,85
    ,96
    ,135
    ,167
    ,171
    ,120
    ,140
    ,109
    ,98
    ,95
    ,139
    ,159
    ,170
    ,131
    ,98
    ,104
    ,82
    ,104
    ,104
    ,149
    ,171
    ,83
    ,132
    ,125
    ,122
    ,200
    ,72
    ,111
    ,170
    ,112
    ,141
    ,121
    ,98
    ,160
    ,131
    ,114
    ,121
    ,135
    ,161
    ,108
    ,110
    ,149
    ,115
    ,92
    ,153
    ,123
    ,131
    ,143
    ,91
    ,164
    ,125
    ,88
    ,169
    ,159
    ,153
    ,112
    ,105
    ,110
    ,114
    ,146
    ,159
    ,170
    ,194
    ,109
    ,23
    ,128
    ,144
    ,139
    ,128
    ,114
    ,143
    ,113
    ,112
    ,114
    ,102
    ,165
    ,134
    ,130
    ,127
    ,90
    ,127
    ,158
    ,106
    ,141
    ,136
    ,79
    ,154
    ,210
    ,149
    ,109
    ,76
    ,118
    ,176
    ,114
    ,196
    ,90
    ,91
    ,133
    ,80
    ,163
    ,162
    ,142
    ,132
    ,107
    ,109
    ,104
    ,106
    ,125
    ,103
    ,155
    ,164
    ,68
    ,103
    ,140
    ,103
    ,170
    ,137
    ,136
    ,152
    ,83
    ,131
    ,155
    ,108
    ,103
    ,124
    ,159
    ,139
    ,114
    ,162
    ,103
    ,123
    ,194
    ,111
    ,115
    ,152
    ,99
    ,166
    ,122
    ,62
    ,130
    ,151
    ,137
    ,133
    ,140
    ,125
    ,118
    ,132
    ,85
    ,103
    ,177
    ,160
    ,104
    ,157
    ,132
    ,70
    ,152
    ,110
    ,156
    ,180
    ,154
    ,69
    ,75
    ,122
    ,139
    ,136
    ,171
    ,196
    ,41
    ,124
    ,106
    ,98
    ,201
    ,140
    ,144
    ,115
    ,113
    ,86
    ,110
    ,219
    ,125
    ,69
    ,153
    ,135
    ,124
    ,168
    ,103
    ,106
    ,155
    ,108
    ,61
    ,173
    ,152
    ,82
    ,153
    ,107
    ,108
    ,131
    ,151
    ,119
    ,92
    ,216
    ,97
    ,53
    ,144
    ,138
    ,147
    ,162
    ,146
    ,118
    ,134
    ,98
    ,136
    ,122
    ,157
    ,140
    ,130
    ,162
    ,99
    ,157
    ,71
    ,113
    ,223
    ,170
    ,139
    ,109
    ,106
    ,88
    ,85
    ,135
    ,170
    ,118
    ,109
    ,115
    ,84
    ,125
    ,139
    ,75
    ,136
    ,156
    ,89
    ,114
    ,93
    ,162
    ,168
    ,105
    ,147
    ,77
    ,155
    ,183
    ,82
    ,170
    ,130
    ,101
    ,179
    ,113
    ,137
    ,163
    ,126
    ,102
    ,125
    ,162
    ,129
    ,103
    ,124
    ,147
    ,147
    ,121
    ,52
    ,114
    ,167
    ,118
    ,163
    ,164
    ,71
    ,143
    ,116
    ,101
    ,155
    ,127
    ,128
    ,172
    ,144
    ,105
    ,111
    ,75
    ,157
    ,142
    ,157
    ,153
    ,91
    ,130
    ,76
    ,117
    ,137
    ,130
    ,165
    ,112
    ,113
    ,105
    ,132
    ,129
    ,142
    ,160
    ,109
    ,116
    ,66
    ,128
    ,190
    ,132
    ,113
    ,98
    ,136
    ,153
    ,135
    ,160
    ,89
    ,118
    ,132
    ,111
    ,145
    ,102
    ,136
    ,130
    ,149
    ,146
    ,128
    ,144
    ,94
    ,156
    ,162
    ,112
    ,126
    ,88
    ,106
    ,144
    ,151
    ,143
    ,206
    ,137
    ,100
    ,120
    ,85
    ,104
    ,122
    ,172
    ,133
    ,139
    ,47
    ,104
    ,150
    ,121
    ,187
    ,132
    ,149
    ,107
    ,100
    ,96
    ,98
    ,189
    ,153
    ,129
    ,114
    ,58
    ,126
    ,199
    ,138
    ,162
    ,157
    ,52
    ,67
    ,123
    ,211
    ,127
    ,145
    ,166
    ,78
    ,153
    ,178
    ,106
    ,121
    ,115
    ,154
    ,117
    ,67
    ,162
    ,133
    ,134
    ,110
    ,134
    ,94
    ,105
    ,158
    ,128
    ,155
    ,125
    ,62
    ,110
    ,106
    ,136
    ,133
    ,120
    ,170
    ,170
    ,136
    ,86
    ,118
    ,125
    ,116
    ,126
    ,158
    ,166
    ,128
    ,100
    ,139
    ,153
    ,106
    ,124
    ,128
    ,112
    ,124
    ,154
    ,89
    ,99
    ,163
    ,175
    ,124
    ,109
    ,114
    ,122
    ,176
    ,129
    ,160
    ,61
    ,81
    ,123
    ,138
    ,156
    ,107
    ,120
    ,152
    ,70
    ,146
    ,213
    ,126
    ,97
    ,108
    ,125
    ,138
    ,148
    ,183
    ,136
    ,106
    ,134
    ,70
    ,152
    ,148
    ,147
    ,123
    ,146
    ,73
    ,121
    ,148
    ,91
    ,133
    ,160
    ,113
    ,81
    ,150
    ,150
    ,90
    ,154
    ,129
    ,70
    ,149
    ,151
    ,136
    ,119
    ,172
    ,118
    ,139
    ,114
    ,105
    ,124
    ,161
    ,148
    ,92
    ,116
    ,100
    ,133
    ,181
    ,101
    ,120
    ,141
    ,97
    ,133
    ,146
    ,159
    ,104
    ,106
    ,154
    ,123
    ,101
    ,182
    ,103
    ,86
    ,181
    ,121
    ,131
    ,190
    ,110
    ,73
    ,110
    ,152
    ,147
    ,174
    ,160
    ,45
    ,112
    ,181
    ,111
    ,116
    ,182
    ,113
    ,83
    ,132
    ,100
    ,152
    ,200
    ,83
    ,59
    ,138
    ,165
    ,148
    ,105
    ,133
    ,96
    ,124
    ,120
    ,100
    ,149
    ,132
    ,133
    ,163
    ,150
    ,102
    ,114
    ,135
    ,148
    ,137
    ,159
    ,110
    ,10
    ,138
    ,201
    ,93
    ,155
    ,116
    ,114
    ,129
    ,133
    ,140
    ,137
    ,152
    ,116
    ,100
    ,117
    ,143
    ,134
    ,169
    ,112
    ,121
    ,160
    ,111
    ,113
    ,147
    ,130
    ,114
    ,139
    ,120
    ,128
    ,162
    ,125
    ,122
    ,120
    ,154
    ,155
    ,106
    ,119
    ,84
    ,130
    ,150
    ,128
    ,129
    ,94
    ,118
    ,156
    ,153
    ,108
    ,102
    ,148
    ,123
    ,90
    ,122
    ,121
    ,92
    ,170
    ,173
    ,100
    ,112
    ,117
    ,135
    ,140
    ,146
    ,104
    ,107
    ,99
    ,138
    ,150
    ,147
    ,103
    ,81
    ,159
    ,148
    ,149
    ,109
    ,130
    ,109
    ,109
    ,169
    ,143
    ,109
    ,130
    ,138
    ,127
    ,176
    ,110
    ,133
    ,163
    ,113
    ,147
    ,94
    ,78
    ,142
    ,146
    ,162
    ,128
    ,173
    ,84
    ,52
    ,200
    ,182
    ,101
    ,109
    ,125
    ,83
    ,154
    ,138
    ,135
    ,122
    ,147
    ,153
    ,71
    ,127
    ,133
    ,127
    ,147
    ,131
    ,109
    ,109
    ,102
    ,114
    ,164
    ,145
    ,113
    ,129
    ,135
    ,110
    ,131
    ,128
    ,132
    ,127
    ,111
    ,133
    ,128
    ,126
    ,123
    ,151
    ,107
    ,111
    ,125
    ,112
    ,132
    ,152
    ,142
    ,108
    ,156
    ,138
    ,91
    ,108
    ,149
    ,164
    ,133
    ,126
    ,125
    ,66
    ,117
    ,168
    ,149
    ,135
    ,172
    ,78
    ,90
    ,159
    ,171
    ,142
    ,117
    ,124
    ,133
    ,126
    ,102
    ,133
    ,137
    ,181
    ,104
    ,117
    ,143
    ,110
    ,120
    ,167
    ,129
    ,129
    ,133
    ,66
    ,106
    ,127
    ,132
    ,162
    ,108
    ,118
    ,124
    ,115
    ,116
    ,136
    ,152
    ,121
    ,89
    ,103
    ,172
    ,102
    ,165
    ,167
    ,112
    ,104
    ,103
    ,130
    ,104
    ,197
    ,172
    ,69
    ,94
    ,168
    ,132
    ,129
    ,146
    ,170
    ,127
    ,54
    ,159
    ,110
    ,109
    ,167
    ,92
    ,145
    ,164
    ,98
    ,132
    ,110
    ,98
    ,176
    ,160
    ,96
    ,88
    ,131
    ,138
    ,138
    ,188
    ,122
    ,113
    ,120
    ,105
    ,126
    ,129
    ,166
    ,147
    ,113
    ,105
    ,113
    ,109
    ,153
    ,162
    ,115
    ,97
    ,102
    ,129
    ,136
    ,134
    ,132
    ,110
    ,129
    ,105
    ,149
    ,125
    ,146
    ,173
    ,134
    ,139
    ,90
    ,127
    ,118
    ,118
    ,188
    ,173
    ,58
    ,88
    ,115
    ,115
    ,171
    ,161
    ,69
    ,106
    ,135
    ,127
    ,139
    ,131
    ,105
    ,120
    ,142
    ,121
    ,124
    ,146
    ,140
    ,120
    ,154
    ,150
    ,113
    ,137
    ,144
    ,78
    ,179
    ,135
    ,127
    ,151
    ,89
    ,152
    ,122
    ,110
    ,145
    ,146
    ,97
    ,126
    ,164
    ,119
    ,146
    ,146
    ,107
    ,126
    ,113
    ,124
    ,134
    ,149
    ,125
    ,86
    ,130
    ,128
    ,89
    ,145
    ,162
    ,110
    ,153
    ,106
    ,107
    ,96
    ,145
    ,155
    ,114
    ,170
    ,114
    ,109
    ,146
    ,148
    ,112
    ,127
    ,146
    ,127
    ,81
    ,125
    ,149
    ,123
    ,129
    ,129
    ,105
    ,94
    ,131
    ,156
    ,132
    ,130
    ,121
    ,120
    ,117
    ,123
    ,185
    ,144
    ,98
    ,116
    ,141
    ,101
    ,141
    ,154
    ,127
    ,73
    ,159
    ,135
    ,88
    ,140
    ,137
    ,150
    ,118
    ,138
    ,125
    ,88
    ,97
    ,139
    ,185
    ,149
    ,81
    ,131
    ,134
    ,121
    ,154
    ,151
    ,89
    ,129
    ,171
    ,160
    ,105
    ,103
    ,163
    ,107
    ,126
    ,146
    ,110
    ,123
    ,121
    ,115
    ,155
    ,132
    ,102
    ,120
    ,122
    ,131
    ,157
    ,145
    ,84
    ,127
    ,138
    ,112
    ,117
    ,161
    ,121
    ,114
    ,116
    ,94
    ,132
    ,137
    ,171
    ,115
    ,110
    ,101
    ,76
    ,182
    ,167
    ,132
    ,118
    ,122
    ,102
    ,98
    ,183
    ,151
    ,124
    ,150
    ,133
    ,130
    ,149
    ,119
    ,132
    ,120
    ,128
    ,127
    ,132
    ,107
    ,102
    ,154
    ,124
    ,123
    ,130
    ,102
    ,122
    ,129
    ,134
    ,116
    ,122
    ,163
    ,102
    ,128
    ,145
    ,120
    ,142
    ,167
    ,113
    ,121
    ,128
    ,138
    ,111
    ,131
    ,178
    ,93
    ,123
    ,121
    ,138
    ,155
    ,128
    ,116
    ,114
    ,136
    ,98
    ,109
    ,122
    ,90
    ,160
    ,159
    ,151
    ,120
    ,76
    ,106
    ,168
    ,181
    ,159
    ,58
    ,105
    ,172
    ,76
    ,185
    ,127
    ,102
    ,143
    ,96
    ,150
    ,120
    ,142
    ,142
    ,88
    ,142
    ,129
    ,145
    ,135
    ,86
    ,138
    ,181
    ,142
    ,85
    ,111
    ,161
    ,123
    ,116
    ,141
    ,96
    ,162
    ,141
    ,94
    ,150
    ,136
    ,106
    ,147
    ,129
    ,108
    ,155
    ,129
    ,112
    ,140
    ,135
    ,91
    ,117
    ,150
    ,142
    ,128
    ,125
    ,137
    ,120
    ,121
    ,117
    ,91
    ,117
    ,131
    ,145
    ,113
    ,129
    ,129
    ,105
    ,122
    ,130
    ,163
    ,146
    ,121
    ,103
    ,137
    ,127
    ,145
    ,146
    ,128
    ,142
    ,117
    ,126
    ,147
    ,122
    ,148
    ,123
    ,87
    ,135
    ,117
    ,94
    ,125
    ,140
    ,138
    ,137
    ,130
    ,141
    ,104
    ,133
    ,127
    ,139
    ,158
    ,90
    ,138
    ,141
    ,131
    ,154
    ,111
    ,132
    ,130
    ,117
    ,174
    ,132
    ,116
    ,111
    ,128
    ,119
    ,119
    ,156
    ,105
    ,127
    ,157
    ,135
    ,109
    ,117
    ,135
    ,107
    ,116
    ,128
    ,142
    ,145
    ,109
    ,130
    ,141
    ,111
    ,145
    ,143
    ,100
    ,127
    ,96
    ,124
    ,136
    ,127
    ,164
    ,101
    ,115
    ,150
    ,128
    ,176
    ,133
    ,90
    ,117
    ,111
    ,162
    ,127
    ,134
    ,145
    ,100
    ,101
    ,160
    ,165
    ,100
    ,141
    ,110
    ,81
    ,158
    ,115
    ,97
    ,139
    ,141
    ,144
    ,109
    ,155
    ,108
    ,100
    ,174
    ,145
    ,149
    ,144
    ,83
    ,96
    ,146
    ,154
    ,160
    ,106
    ,108
    ,111
    ,133
    ,149
    ,95
    ,136
    ,141
    ,104
    ,146
    ,137
    ,106
    ,135
    ,138
    ,131
    ,140
    ,158
    ,89
    ,74
    ,156
    ,169
    ,141
    ,128
    ,107
    ,123
    ,144
    ,123
    ,106
    ,141
    ,141
    ,132
    ,91
    ,108
    ,119
    ,127
    ,163
    ,120
    ,128
    ,124
    ,97
    ,136
    ,136
    ,140
    ,136
    ,87
    ,133
    ,134
    ,123
    ,158
    ,146
    ,137
    ,154
    ,94
    ,104
    ,140
    ,131
    ,140
    ,127
    ,106
    ,138
    ,132
    ,117
    ,131
    ,143
    ,134
    ,112
    ,131
    ,101
    ,154
    ,130
    ,94
    ,130
    ,151
    ,151
    ,95
    ,107
    ,148
    ,157
    ,146
    ,116
    ,112
    ,120
    ,121
    ,147
    ,145
    ,104
    ,114
    ,158
    ,132
    ,115
    ,125
    ,114
    ,99
    ,142
    ,157
    ,136
    ,103
    ,106
    ,134
    ,151
    ,142
    ,120
    ,125
    ,125
    ,105
    ,144
    ,146
    ,126
    ,119
    ,130
    ,109
    ,114
    ,161
    ,135
    ,134
    ,120
    ,138
    ,115
    ,96
    ,132
    ,121
    ,141
    ,164
    ,87
    ,103
    ,154
    ,124
    ,172
    ,140
    ,121
    ,112
    ,119
    ,140
    ,101
    ,161
    ,149
    ,107
    ,129
    ,129
    ,120
    ,154
    ,134
    ,105
    ,123
    ,147
    ,134
    ,107
    ,113
    ,122
    ,139
    ,141
    ,137
    ,146
    ,121
    ,106
    ,113
    ,140
    ,144
    ,126
    ,106
    ,94
    ,125
    ,137
    ,172
    ,133
    ,99
    ,129
    ,121
    ,105
    ,126
    ,167
    ,129
    ,103
    ,129
    ,149
    ,123
    ,107
    ,126
    ,145
    ,163
    ,125
    ,96
    ,103
    ,110
    ,166
    ,131
    ,106
    ,129
    ,122
    ,110
    ,153
    ,148
    ,156
    ,123
    ,89
    ,138
    ,123
    ,145
    ,125
    ,126
    ,149
    ,149
    ,94
    ,131
    ,143
    ,120
    ,146
    ,101
    ,120
    ,122
    ,128
    ,152
    ,98
    ,131
    ,146
    ,109
    ,120
    ,149
    ,137
    ,152
    ,102
    ,110
    ,172
    ,99
    ,118
    ,148
    ,131
    ,149
    ,151
    ,117
    ,112
    ,129
    ,124
    ,113
    ,121
    ,156
    ,99
    ,89
    ,139
    ,113
    ,164
    ,157
    ,101
    ,123
    ,88
    ,119
    ,174
    ,127
    ,118
    ,141
    ,112
    ,139
    ,134
    ,130
    ,136
    ,141
    ,125
    ,116
    ,138
    ,129
    ,118
    ,105
    ,159
    ,115
    ,132
    ,138
    ,92
    ,124
    ,139
    ,156
    ,132
    ,103
    ,118
    ,109
    ,118
    ,175
    ,162
    ,109
    ,123
    ,113
    ,113
    ,149
    ,170
    ,126
    ,90
    ,137
    ,115
    ,133
    ,140
    ,106
    ,129
    ,136
    ,125
    ,117
    ,139
    ,97
    ,126
    ,159
    ,144
    ,132
    ,113
    ,93
    ,121
    ,185
    ,133
    ,112
    ,127
    ,128
    ,134
    ,131
    ,121
    ,134
    ,135
    ,118
    ,122
    ,111
    ,145
    ,121
    ,108
    ,157
    ,140
    ,86
    ,140
    ,138
    ,122
    ,173
    ,128
    ,100
    ,108
    ,116
    ,162
    ,110
    ,116
    ,152
    ,125
    ,127
    ,109
    ,140
    ,162
    ,116
    ,119
    ,157
    ,93
    ,110
    ,135
    ,133
    ,145
    ,136
    ,122
    ,116
    ,120
    ,137
    ,122
    ,135
    ,148
    ,135
    ,88
    ,130
    ,131
    ,142
    ,158
    ,119
    ,112
    ,116
    ,138
    ,100
    ,125
    ,138
    ,124
    ,87
    ,130
    ,146
    ,116
    ,146
    ,125
    ,104
    ,156
    ,149
    ,111
    ,91
    ,128
    ,156
    ,155
    ,129
    ,100
    ,123
    ,130
    ,145
    ,145
    ,147
    ,118
    ,117
    ,114
    ,127
    ,131
    ,162
    ,122
    ,112
    ,144
    ,103
    ,118
    ,129
    ,138
    ,143
    ,122
    ,119
    ,133
    ,113
    ,115
    ,154
    ,143
    ,142
    ,128
    ,91
    ,136
    ,110
    ,131
    ,139
    ,140
    ,131
    ,104
    ,129
    ,137
    ,139
    ,144
    ,140
    ,108
    ,110
    ,126
    ,121
    ,125
    ,141
    ,131
    ,101
    ,108
    ,156
    ,127
    ,110
    ,156
    ,122
    ,109
    ,150
    ,117
    ,105
    ,140
    ,143
    ,145
    ,138
    ,133
    ,136
    ,101
    ,139
    ,151
    ,139
    ,137
    ,97
    ,128
    ,123
    ,126
    ,130
    ,141
    ,128
    ,128
    ,126
    ,80
    ,147
    ,157
    ,118
    ,125
    ,108
    ,124
    ,108
    ,117
    ,156
    ,145
    ,128
    ,129
    ,83
    ,132
    ,181
    ,91
    ,128
    ,142
    ,140
    ,132
    ,105
    ,126
    ,131
    ,149
    ,169
    ,129
    ,86
    ,126
    ,131
    ,128
    ,153
    ,148
    ,117
    ,75
    ,112
    ,152
    ,166
    ,133
    ,116
    ,88
    ,116
    ,157
    ,124
    ,146
    ,121
    ,141
    ,136
    ,95
    ,141
    ,146
    ,123
    ,136
    ,107
    ,138
    ,147
    ,78
    ,136
    ,137
    ,132
    ,164
    ,100
    ,100
    ,121
    ,128
    ,124
    ,138
    ,128
    ,113
    ,127
    ,132
    ,147
    ,129
    ,157
    ,132
    ,91
    ,151
    ,131
    ,94
    ,143
    ,170
    ,126
    ,131
    ,129
    ,99
    ,133
    ,147
    ,110
    ,135
    ,132
    ,123
    ,113
    ,83
    ,171
    ,125
    ,111
    ,141
    ,108
    ,133
    ,113
    ,124
    ,147
    ,130
    ,124
    ,119
    ,109
    ,131
    ,140
    ,146
    ,158
    ,110
    ,117
    ,115
    ,127
    ,169
    ,141
    ,129
    ,129
    ,123
    ,104
    ,130
    ,136
    ,144
    ,144
    ,94
    ,111
    ,110
    ,140
    ,156
    ,100
    ,126
    ,145
    ,111
    ,112
    ,133
    ,127
    ,150
    ,145
    ,128
    ,110
    ,115
    ,134
    ,133
    ,147
    ,153
    ,130
    ,86
    ,120
    ,145
    ,128
    ,150
    ,132
    ,106
    ,117
    ,119
    ,134
    ,129
    ,123
    ,154
    ,127
    ,95
    ,121
    ,120
    ,138
    ,130
    ,152
    ,143
    ,106
    ,98
    ,137
    ,158
    ,142
    ,148
    ,125
    ,120
    ,113
    ,125
    ,141
    ,142
    ,150
    ,130
    ,88
    ,119
    ,132
    ,119
    ,152
    ,138
    ,105
    ,129
    ,109
    ,125
    ,126
    ,151
    ,125
    ,99
    ,156
    ,116
    ,105
    ,113
    ,116
    ,156
    ,156
    ,127
    ,98
    ,117
    ,142
    ,136
    ,169
    ,130
    ,113
    ,109
    ,114
    ,170
    ,129
    ,133
    ,135
    ,77
    ,138
    ,147
    ,104
    ,131
    ,149
    ,109
    ,126
    ,115
    ,104
    ,141
    ,140
    ,124
    ,125
    ,158
    ,114
    ,98
    ,130
    ,138
    ,145
    ,129
    ,143
    ,116
    ,119
    ,142
    ,133
    ,146
    ,137
    ,119
    ,123
    ,118
    ,122
    ,137
    ,126
    ,139
    ,122
    ,124
    ,119
    ,120
    ,140
    ,153
    ,135
    ,116
    ,127
    ,103
    ,136
    ,134
    ,102
    ,143
    ,117
    ,134
    ,133
    ,115
    ,154
    ,119
    ,110
    ,132
    ,122
    ,136
    ,137
    ,107
    ,155
    ,134
    ,117
    ,139
    ,111
    ,127
    ,139
    ,116
    ,151
    ,118
    ,101
    ,141
    ,122
    ,115
    ,147
    ,143
    ,125
    ,132
    ,117
    ,126
    ,121
    ,138
    ,139
    ,91
    ,125
    ,150
    ,126
    ,147
    ,109
    ,106
    ,157
    ,142
    ,126
    ,126
    ,108
    ,123
    ,138
    ,124
    ,152
    ,113
    ,111
    ,134
    ,136
    ,147
    ,134
    ,111
    ,122
    ,139
    ,118
    ,142
    ,112
    ,116
    ,139
    ,137
    ,129
    ,106
    ,162
    ,120
    ,108
    ,146
    ,116
    ,135
    ,126
    ,106
    ,117
    ,172
    ,145
    ,109
    ,131
    ,123
    ,133
    ,132
    ,139
    ,134
    ,118
    ,119
    ,116
    ,113
    ,128
    ,152
    ,136
    ,119
    ,127
    ,127
    ,128
    ,116
    ,124
    ,148
    ,121
    ,118
    ,129
    ,123
    ,132
    ,139
    ,139
    ,138
    ,112
    ,108
    ,138
    ,128
    ,127
    ,147
    ,110
    ,138
    ,131
    ,112
    ,149
    ,117
    ,121
    ,138
    ,113
    ,117
    ,134
    ,123
    ,125
    ,136
    ,143
    ,127
    ,140
    ,136
    ,115
    ,155
    ,111
    ,112
    ,156
    ,93
    ,103
    ,146
    ,145
    ,129
    ,131
    ,128
    ,119
    ,134
    ,123
    ,118
    ,116
    ,132
    ,142
    ,111
    ,127
    ,124
    ,125
    ,156
    ,127
    ,142
    ,136
    ,98
    ,120
    ,124
    ,155
    ,123
    ,117
    ,124
    ,120
    ,149
    ,141
    ,126
    ,127
    ,136
    ,117
    ,120
    ,127
    ,128
    ,121
    ,126
    ,147
    ,117
    ,136
    ,141
    ,95
    ,153
    ,151
    ,97
    ,117
    ,118
    ,122
    ,140
    ,143
    ,128
    ,116
    ,137
    ,126
    ,109
    ,140
    ,163
    ,136
    ,113
    ,120
    ,118
    ,130
    ,142
    ,136
    ,130
    ,116
    ,133
    ,111
    ,121
    ,141
    ,122
    ,127
    ,122
    ,132
    ,139
    ,105
    ,132
    ,159
    ,135
    ,138
    ,117
    ,106
    ,127
    ,118
    ,152
    ,140
    ,110
    ,127
    ,121
    ,119
    ,148
    ,149
    ,88
    ,137
    ,112
    ,118
    ,144
    ,99
    ,132
    ,153
    ,119
    ,127
    ,90
    ,137
    ,146
    ,122
    ,161
    ,130
    ,116
    ,105
    ,124
    ,138
    ,147
    ,149
    ,151
    ,104
    ,108
    ,135
    ,134
    ,129
    ,146
    ,138
    ,119
    ,126
    ,123
    ,125
    ,129
    ,137
    ,135
    ,120
    ,116
    ,109
    ,123
    ,158
    ,128
    ,120
    ,118
    ,113
    ,113
    ,136
    ,139
    ,133
    ,144
    ,130
    ,107
    ,127
    ,144
    ,130
    ,125
    ,134
    ,129
    ,124
    ,119
    ,127
    ,136
    ,148
    ,130
    ,107
    ,149
    ,98
    ,119
    ,156
    ,129
    ,132
    ,118
    ,97
    ,127
    ,135
    ,151
    ,127
    ,124
    ,151
    ,106
    ,114
    ,137
    ,125
    ,135
    ,132
    ,110
    ,134
    ,128
    ,121
    ,123
    ,135
    ,146
    ,131
    ,108
    ,112
    ,120
    ,128
    ,158
    ,131
    ,120
    ,129
    ,108
    ,114
    ,152
    ,157
    ,129
    ,112
    ,114
    ,137
    ,128
    ,137
    ,122
    ,127
    ,154
    ,123
    ,128
    ,137
    ,118
    ,139
    ,152
    ,113
    ,115
    ,126
    ,100
    ,129
    ,159
    ,141
    ,123
    ,102
    ,117
    ,125
    ,129
    ,144
    ,130
    ,113
    ,120
    ,121
    ,114
    ,142
    ,136
    ,127
    ,129
    ,112
    ,130
    ,128
    ,135
    ,141
    ,118
    ,135
    ,122
    ,115
    ,143
    ,144
    ,119
    ,140
    ,150
    ,102
    ,130
    ,135
    ,117
    ,146
    ,126
    ,128
    ,137
    ,129
    ,131
    ,119
    ,135
    ,136
    ,127
    ,117
    ,119
    ,119
    ,154
    ,119
    ,101
    ,132
    ,128
    ,122
    ,118
    ,142
    ,144
    ,117
    ,128
    ,120
    ,110
    ,138
    ,146
    ,109
    ,137
    ,156
    ,112
    ,128
    ,122
    ,133
    ,136
    ,131
    ,117
    ,130
    ,134
    ,135
    ,108
    ,147
    ,146
    ,97
    ,139
    ,132
    ,101
    ,125
    ,130
    ,125
    ,143
    ,124
    ,107
    ,119
    ,132
    ,145
    ,158
    ,113
    ,108
    ,138
    ,133
    ,126
    ,132
    ,126
    ,126
    ,113
    ,128
    ,165
    ,120
    ,123
    ,142
    ,118
    ,140
    ,135
    ,95
    ,120
    ,130
    ,145
    ,131
    ,112
    ,126
    ,112
    ,128
    ,153
    ,132
    ,137
    ,126
    ,99
    ,125
    ,148
    ,126
    ,145
    ,132
    ,119
    ,131
    ,116
    ,156
    ,136
    ,114
    ,119
    ,122
    ,126
    ,126
    ,125
    ,132
    ,114
    ,130
    ,154
    ,101
    ,129
    ,143
    ,101
    ,132
    ,131
    ,126
    ,132
    ,116
    ,125
    ,152
    ,127
    ,138
    ,128
    ,99
    ,147
    ,134
    ,123
    ,126
    ,121
    ,143
    ,136
    ,102
    ,138
    ,138
    ,115
    ,150
    ,114
    ,117
    ,131
    ,110
    ,135
    ,140
    ,137
    ,122
    ,108
    ,145
    ,143
    ,109
    ,127
    ,134
    ,115
    ,144
    ,121
    ,113
    ,134
    ,140
    ,126
    ,121
    ,143
    ,133
    ,115
    ,119
    ,137
    ,130
    ,128
    ,136
    ,126
    ,121
    ,137
    ,131
    ,128
    ,127
    ,137
    ,115
    ,116
    ,142
    ,131
    ,123
    ,118
    ,123
    ,151
    ,126
    ,124
    ,130
    ,129
    ,132
    ,121
    ,136
    ,119
    ,131
    ,121
    ,125
    ,146
    ,134
    ,129
    ,115
    ,120
    ,135
    ,139
    ,126
    ,114
    ,111
    ,144
    ,126
    ,109
    ,151
    ,125
    ,122
    ,125
    ,121
    ,136
    ,126
    ,115
    ,127
    ,140
    ,127
    ,132
    ,134
    ,125
    ,131
    ,131
    ,126
    ,139
    ,142
    ,110
    ,117
    ,134
    ,135
    ,148
    ,121
    ,121
    ,127
    ,136
    ,131
    ,119
    ,127
    ,122
    ,125
    ,113
    ,128
    ,133
    ,124
    ,130
    ,125
    ,127
    ,130
    ,120
    ,130
    ,140
    ,127
    ,134
    ,123
    ,125
    ,133
    ,132
    ,129
    ,126
    ,130
    ,134
    ,117
    ,116
    ,137
    ,130
    ,119
    ,127
    ,132
    ,127
    ,122
    ,127
    ,135
    ,125
    ,135
    ,125
    ,128
    ,136
    ,119
    ,126
    ,145
    ,135
    ,135
    ,126
    ,115
    ,146
    ,140
    ,123
    ,109
    ,128
    ,139
    ,127
    ,115
    ,132
    ,133
    ,126
    ,127
    ,110
    ,138
    ,132
    ,117
    ,116
    ,132
    ,133
    ,126
    ,107
    ,133
    ,142
    ,134
    ,136
    ,107
    ,131
    ,137
    ,116
    ,131
    ,142
    ,137
    ,122
    ,120
    ,134
    ,143
    ,136
    ,127
    ,135
    ,122
    ,127
    ,121
    ,117
    ,125
    ,132
    ,124
    ,113
    ,134
    ,145
    ,118
    ,112
    ,127
    ,126
    ,137
    ,126
    ,106
    ,131
    ,133
    ,131
    ,142
    ,128
    ,129
    ,131
    ,132
    ,125
    ,133
    ,137
    ,125
    ,115
    ,142
    ,138
    ,108
    ,128
    ,139
    ,131
    ,131
    ,119
    ,112
    ,129
    ,132
    ,130
    ,128
    ,119
    ,127
    ,129
    ,122
    ,142
    ,136
    ,134
    ,120
    ,115
    ,136
    ,135
    ,120
    ,131
    ,146
    ,132
    ,122
    ,126
    ,124
    ,122
    ,127
    ,124
    ,124
    ,125
    ,131
    ,109
    ,134
    ,147
    ,132
    ,125
    ,116
    ,123
    ,143
    ,132
    ,124
    ,131
    ,129
    ,110
    ,125
    ,154
    ,146
    ,120
    ,117
    ,134
    ,125
    ,132
    ,128
    ,111
    ,132
    ,138
    ,116
    ,132
    ,129
    ,128
    ,125
    ,122
    ,138
    ,133
    ,105
    ,116
    ,132
    ,137
    ,142
    ,122
    ,122
    ,125
    ,134
    ,133
    ,123
    ,131
    ,137
    ,121
    ,118
    ,130
    ,126
    ,132
    ,128
    ,134
    ,142
    ,119
    ,128
    ,141
    ,119
    ,128
    ,124
    ,114
    ,133
    ,133
    ,124
    ,125
    ,142
    ,140
    ,120
    ,125
    ,125
    ,123
    ,136
    ,136
    ,114
    ,128
    ,137
    ,119
    ,119
    ,135
    ,148
    ,119
    ,125
    ,133
    ,113
    ,121
    ,131
    ,127
    ,130
    ,135
    ,130
    ,115
    ,128
    ,149
    ,137
    ,113
    ,120
    ,134
    ,117
    ,122
    ,137
    ,121
    ,134
    ,136
    ,122
    ,139
    ,131
    ,129
    ,121
    ,121
    ,142
    ,125
    ,121
    ,121
    ,134
    ,138
    ,127
    ,132
    ,117
    ,129
    ,134
    ,125
    ,117
    ,127
    ,133
    ,124
    ,109
    ,135
    ,148
    ,119
    ,128
    ,127
    ,120
    ,127
    ,135
    ,130
    ,127
    ,136
    ,122
    ,116
    ,141
    ,136
    ,123
    ,120
    ,135
    ,140
    ,129
    ,126
    ,122
    ,121
    ,137
    ,125
    ,126
    ,124
    ,126
    ,128
    ,120
    ,136
    ,134
    ,119
    ,123
    ,135
    ,131
    ,122
    ,130
    ,128
    ,123
    ,128
    ,124
    ,142
    ,127
    ,130
    ,127
    ,123
    ,130
    ,134
    ,128
    ,122
    ,133
    ,137
    ,117
    ,117
    ,146
    ,121
    ,123
    ,135
    ,128
    ,127
    ,121
    ,130
    ,125
    ,130
    ,137
    ,118
    ,129
    ,142
    ,122
    ,126
    ,130
    ,120
    ,132
    ,133
    ,120
    ,131
    ,128
    ,121
    ,128
    ,129
    ,143
    ,123
    ,120
    ,139
    ,120
    ,137
    ,135
    ,107
    ,126
    ,135
    ,131
    ,138
    ,123
    ,123
    ,130
    ,129
    ,130
    ,125
    ,129
    ,126
    ,120
    ,132
    ,126
    ,123
    ,136
    ,127
    ,123
    ,134
    ,136
    ,117
    ,125
    ,138
    ,125
    ,124
    ,130
    ,135
    ,124
    ,124
    ,130
    ,135
    ,142
    ,126
    ,114
    ,127
    ,125
    ,131
    ,126
    ,123
    ,130
    ,126
    ,127
    ,127
    ,130
    ,127
    ,126
    ,129
    ,130
    ,132
    ,130
    ,121
    ,126
    ,143
    ,133
    ,123
    ,123
    ,138
    ,131
    ,123
    ,139
    ,126
    ,127
    ,127
    ,124
    ,126
    ,132
    ,128
    ,121
    ,128
    ,130
    ,120
    ,125
    ,118
    ,135
    ,129
    ,125
    ,123
    ,129
    ,132
    ,124
    ,128
    ,136
    ,132
    ,129
    ,133
    ,122
    ,129
    ,136
    ,128
    ,123
    ,125
    ,131
    ,125
    ,125
    ,136
    ,117
    ,139
    ,128
    ,126
    ,133
    ,125
    ,122
    ,123
    ,136
    ,127
    ,120
    ,126
    ,124
    ,122
    ,138
    ,129
    ,130
    ,133
    ,127
    ,123
    ,131
    ,121
    ,131
    ,137
    ,124
    ,127
    ,130
    ,134
    ,130
    ,123
    ,137
    ,124
    ,121
    ,144
    ,123
    ,118
    ,127
    ,133
    ,133
    ,126
    ,125
    ,123
    ,121
    ,125
    ,134
    ,133
    ,121
    ,120
    ,122
    ,135
    ,134
    ,128
    ,130
    ,124
    ,131
    ,136
    ,130
    ,125
    ,126
    ,130
    ,134
    ,131
    ,121
    ,125
    ,133
    ,129
    ,122
    ,128
    ,126
    ,126
    ,124
    ,125
    ,128
    ,129
    ,133
    ,123
    ,125
    ,130
    ,128
    ,129
    ,131
    ,133
    ,124
    ,131
    ,127
    ,133
    ,142
    ,122
    ,124
    ,134
    ,141
    ,120
    ,128
    ,126
    ,122
    ,139
    ,123
    ,124
    ,130
    ,130
    ,121
    ,117
    ,144
    ,121
    ,124
    ,130
    ,122
    ,132
    ,124
    ,129
    ,130
    ,129
    ,128
    ,132
    ,123
    ,124
    ,134
    ,124
    ,127
    ,129
    ,126
    ,129
    ,121
    ,129
    ,141
    ,119
    ,124
    ,141
    ,125
    ,123
    ,127
    ,131
    ,129
    ,115
    ,133
    ,134
    ,121
    ,136
    ,125
    ,125
    ,137
    ,125
    ,127
    ,131
    ,124
    ,131
    ,129
    ,131
    ,128
    ,128
    ,121
    ,128
    ,139
    ,127
    ,128
    ,126
    ,127
    ,127
    ,129
    ,127
    ,121
    ,134
    ,133
    ,124
    ,126
    ,127
    ,123
    ,128
    ,129
    ,133
    ,130
    ,120
    ,125
    ,120
    ,133
    ,136
    ,127
    ,132
    ,128
    ,126
    ,126
    ,132
    ,133
    ,122
    ,125
    ,132
    ,126
    ,127
    ,131
    ,130
    ,127
    ,128
    ,135
    ,126
    ,119
    ,123
    ,133
    ,131
    ,126
    ,130
    ,122
    ,118
    ,138
    ,130
    ,133
    ,129
    ,126
    ,126
    ,128
    ,131
    ,127
    ,130
    ,121
    ,130
    ,129
    ,128
    ,120
    ,133
    ,133
    ,128
    ,126
    ,123
    ,123
    ,122
    ,135
    ,129
    ,137
    ,133
    ,117
    ,127
    ,134
    ,131
    ,130
    ,128
    ,128
    ,125
    ,135
    ,126
    ,119
    ,133
    ,135
    ,125
    ,133
    ,130
    ,116
    ,129
    ,127
    ,131
    ,125
    ,126
    ,126
    ,120
    ,134
    ,131
    ,128
    ,132
    ,130
    ,121
    ,124
    ,136
    ,126
    ,133
    ,127
    ,122
    ,133
    ,127
    ,126
    ,130
    ,127
    ,130
    ,128
    ,122
    ,133
    ,130
    ,120
    ,128
    ,129
    ,129
    ,128
    ,127
    ,131
    ,130
    ,130
    ,131
    ,133
    ,122
    ,122
    ,130
    ,130
    ,136
    ,127
    ,126
    ,124
    ,133
    ,130
    ,123
    ,123
    ,126
    ,130
    ,130
    ,127
    ,120
    ,130
    ,128
    ,128
    ,130
    ,127
    ,125
    ,129
    ,127
    ,131
    ,130
    ,130
    ,126
    ,126
    ,131
    ,132
    ,134
    ,127
    ,128
    ,125
    ,125
    ,131
    ,130
    ,132
    ,126
    ,125
    ,132
    ,124
    ,127
    ,130
    ,127
    ,128
    ,125
    ,126
    ,127
    ,124
    ,128
    ,137
    ,126
    ,121
    ,130
    ,131
    ,126
    ,130
    ,127
    ,128
    ,128
    ,123
    ,126
    ,135
    ,134
    ,123
    ,123
    ,130
    ,135
    ,126
    ,125
    ,121
    ,127
    ,136
    ,128
    ,121
    ,129
    ,132
    ,127
    ,128
    ,130
    ,127
    ,122
    ,127
    ,138
    ,131
    ,126
    ,132
    ,125
    ,129
    ,133
    ,128
    ,129
    ,132
    ,122
    ,132
    ,126
    ,121
    ,132
    ,129
    ,124
    ,130
    ,127
    ,128
    ,126
    ,127
    ,126
    ,128
    ,132
    ,127
    ,123
    ,124
    ,133
    ,129
    ,133
    ,131
    ,125
    ,126
    ,132
    ,124
    ,135
    ,129
    ,125
    ,132
    ,122
    ,130
    ,128
    ,129
    ,127
    ,129
    ,129
    ,129
    ,117
    ,130
    ,130
    ,127
    ,132
    ,124
    ,127
    ,125
    ,131
    ,134
    ,128
    ,123
    ,128
    ,127
    ,128
    ,126
    ,131
    ,131
    ,134
    ,123
    ,133
    ,125
    ,125
    ,132
    ,131
    ,132
    ,127
    ,125
    ,118
    ,131
    ,128
    ,130
    ,127
    ,126
    ,124
    ,129
    ,129
    ,127
    ,128
    ,133
    ,125
    ,122
    ,130
    ,133
    ,125
    ,127
    ,133
    ,131
    ,130
    ,126
    ,128
    ,128
    ,128
    ,129
    ,131
    ,128
    ,131
    ,124
    ,125
    ,129
    ,134
    ,129
    ,124
    ,123
    ,127
    ,127
    ,125
    ,128
    ,129
    ,129
    ,127
    ,125
    ,129
    ,135
    ,128
    ,126
    ,128
    ,130
    ,124
    ,126
    ,132
    ,134
    ,127
    ,129
    ,126
    ,128
    ,128
    ,131
    ,126
    ,125
    ,136
    ,124
    ,124
    ,126
    ,133
    ,128
    ,122
    ,128
    ,130
    ,128
    ,130
    ,129
    ,128
    ,122
    ,131
    ,128
    ,130
    ,133
    ,128
    ,127
    ,125
    ,133
    ,134
    ,125
    ,125
    ,129
    ,127
    ,129
    ,124
    ,128
    ,127
    ,127
    ,129
    ,126
    ,127
    ,126
    ,125
    ,130
    ,129
    ,128
    ,132
    ,118
    ,131
    ,128
    ,126
    ,134
    ,129
    ,126
    ,126
    ,127
    ,127
    ,131
    ,129
    ,126
    ,130
    ,129
    ,130
    ,127
    ,128
    ,129
    ,126
    ,131
    ,131
    ,125
    ,126
    ,133
    ,127
    ,131
    ,127
    ,125
    ,126
    ,128
    ,133
    ,127
    ,128
    ,126
    ,123
    ,128
    ,128
    ,128
    ,127
    ,127
    ,130
    ,128
    ,124
    ,131
    ,127
    ,130
    ,130
    ,129
    ,135
    ,121
    ,125
    ,129
    ,131
    ,130
    ,128
    ,125
    ,125
    ,131
    ,127
    ,131
    ,132
    ,129
    ,123
    ,124
    ,129
    ,134
    ,128
    ,127
    ,127
    ,129
    ,132
    ,121
    ,125
    ,132
    ,129
    ,125
    ,127
    ,130
    ,130
    ,127
    ,129
    ,128
    ,130
    ,126
    ,126
    ,126
    ,134
    ,132
    ,125
    ,128
    ,126
    ,130
    ,129
    ,126
    ,128
    ,130
    ,130
    ,124
    ,128
    ,129
    ,125
    ,129
    ,129
    ,132
    ,128
    ,127
    ,123
    ,126
    ,134
    ,128
    ,124
    ,129
    ,126
    ,127
    ,129
    ,134
    ,128
    ,128
    ,129
    ,123
    ,126
    ,129
    ,131
    ,125
    ,128
    ,127
    ,128
    ,130
    ,127
    ,128
    ,130
    ,129
    ,123
    ,130
    ,127
    ,127
    ,130
    ,127
    ,129
    ,126
    ,127
    ,131
    ,127
    ,129
    ,131
    ,128
    ,125
    ,127
    ,128
    ,127
    ,131
    ,133
    ,127
    ,126
    ,128
    ,129
    ,129
    ,124
    ,128
    ,128
    ,128
    ,129
    ,127
    ,126
    ,127
    ,127
    ,129
    ,129
    ,128
    ,129
    ,127
    ,126
    ,128
    ,131
    ,127
    ,127
    ,128
    ,129
    ,128
    ,127
    ,128
    ,132
    ,129
    ,126
    ,127
    ,129
    ,129
    ,125
    ,127
    ,128
    ,128
    ,129
    ,128
    ,128
    ,127
    ,126
    ,128
    ,129
    ,129
    ,129
    ,128
    ,128
    ,129
    ,127
    ,128
    ,128
    ,128
    ,130
    ,130
    ,128
    ,128
    ,126
    ,128
    ,128
    ,128
    ,127
    ,129
    ,127
    ,127
    ,130
    ,127
    ,126
    ,128
    ,129
    ,126
    ,127
    ,127
    ,130
    ,128
    ,129
    ,128
    ,128
    ,129
    ,128
    ,131
    ,128
    ,128
    ,129
    ,126
    ,128
    ,129
    ,128
    ,127
    ,127
    ,129
    ,129
    ,129
    ,127
    ,130
    ,126
    ,125
    ,128
    ,128
    ,129
    ,127
    ,128
    ,126
    ,129
    ,131
    ,128
    ,126
    ,125
    ,130
    ,129
    ,129
    ,130
    ,127
    ,130
    ,127
    ,126
    ,128
    ,129
    ,127
    ,128
    ,130
    ,127
    ,129
    ,126
    ,127
    ,128
    ,129
    ,127
    ,126
    ,129
    ,129
    ,127
    ,129
    ,127
    ,128
    ,130
    ,127
    ,126
    ,131
    ,129
    ,126
    ,127
    ,129
    ,129
    ,128
    ,127
    ,128
    ,126
    ,129
    ,130
    ,126
    ,129
    ,129
    ,125
    ,127
    ,130
    ,127
    ,130
    ,128
    ,127
    ,128
    ,129
    ,126
    ,128
    ,128
    ,127
    ,129
    ,127
    ,130
    ,128
    ,128
    ,129
    ,128
    ,126
    ,129
    ,128
    ,129
    ,130
    ,126
    ,127
    ,130
    ,128
    ,128
    ,129
    ,127
    ,127
    ,129
    ,128
    ,127
    ,129
    ,127
    ,127
    ,128
    ,130
    ,127
    ,127
    ,128
    ,128
    ,129
    ,128
    ,128
    ,129
    ,128
    ,128
    ,128
    ,127
    ,129
    ,128
    ,128
    ,129
    ,127
    ,129
    ,128
    ,125
    ,128
    ,129
    ,129
    ,127
    ,128
    ,128
    ,127
    ,128
    ,129
    ,128
    ,128
    ,129
    ,127
    ,128
    ,129
    ,127
    ,127
    ,128
    ,128
    ,128
    ,128
    ,129
    ,127
    ,127
    ,128
    ,128
    ,129
    ,128
    ,128
    ,128
    ,127
    ,128
    ,130
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,129
    ,128
    ,127
    ,128
    ,127
    ,128
    ,128
    ,128
    ,128
    ,128
    ,129
    ,128
    ,128
    ,127
    ,128
    ,128
    ,129
    ,128
    ,127
    ,128
    ,130
    ,129
    ,128
    ,128
    ,127
    ,127
    ,128
    ,129
    ,128
    ,127
    ,128
    ,128
    ,127
    ,128
    ,128
    ,129
    ,127
    ,128
    ,127
    ,128
    ,127
    ,127
    ,129
    ,128
    ,129
    ,129
    ,128
    ,127
    ,128
    ,128
    ,128
    ,129
    ,129
    ,128
    ,128
    ,127
    ,129
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,127
    ,128
    ,129
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,129
    ,128
    ,127
    ,127
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,129
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,129
    ,128
    ,128
    ,127
    ,127
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,127
    ,127
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,127
    ,128
    ,128
    ,128
    ,128
    ,127
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,127
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,128
    ,127
    ,128
};

int bass_length=4852;
int sample_holder1,sample_holder2;

byte banko=0;

int pot1 = 127;
int pot2=4;
long pot3,pot4;
int kick_sample,snare_sample,sample,hat_sample,noise_sample,bass_sample,B2_freq_sample,B1_freq_sample;

uint32_t accumulator,accumulator2,accumulator3,accumulator4,accumulator5,accu_freq_1,accu_freq_2;

int B2_freq_sequence[128]={
};
int B1_freq_sequence[128]={
};
int sample_sum;

int kf,pf,holdkf,kfe;

uint16_t index,index2,index3,index4,index5,index4b,index_freq_1,index_freq_2,index4bv;
uint16_t indexr,index2r,index3r,index4r,index4br,index2vr,index4vr;

byte noise_mode=1;

byte loopstepf=0;

byte playmode=1;

byte B4_latch, B1_latch;
byte B1_seq_trigger,B3_latch;
byte B2_latch, B2_seq_trigger;
byte B2_seq_latch, B1_seq_latch;

/*************************
 ****** MS DEFINES *******
 *************************/

// the three pins needed to talk to the 74HC595 shift registers
// as for the Alpha firmware jumper setup
const byte LEDlatchPin = 2;
const byte LEDclockPin = 3; // change the 3 to a 6 for the Delta firmware jumper setup
const byte LEDdataPin = 4;

byte LEDrow[5]; // an array of 5 bytes - each byte holds the on/off states for one of the LED rows (8 bits to a byte - 8 LEDs per row)

// the three pins needed to communicate with the CD4021B parallel to serial shift registers (buttons)
// as for the Alpha firmware jumper setup
const byte BUTTONlatchPin = 7;
const byte BUTTONclockPin = 8;
const byte BUTTONdataPin = 9;

// needed by the button debouncer
// based on http://www.adafruit.com/blog/2009/10/20/example-code-for-multi-button-checker-with-debouncing/
#define DEBOUNCE 5
byte pressed[40], justpressed[40], justreleased[40], buttons[40]; // for each of the 40 buttons

// define the byte variables that the button states are read into
byte BUTTONvar[5]; 


// 4051 for the potentiometers
// array of pins used to select 1 of 8 inputs on multiplexer
const byte select[] = {
  17,16,15}; // pins connected to the 4051 input select lines
const byte analogPin = 0;      // the analog pin connected to multiplexer output

int pot[6]; // to store the values of out 6 pots
int potLock[6]; // to lock the pots when they're not being adjusted
byte lockStep; //

// sequencer bytes
byte kick[4];
byte snare[4];
byte hat[4];
byte crash[4];

byte rwBuffer[64];              // our EEPROM read/write buffer

// pitch automation for hat and crash
byte hatAuto[32];
boolean hatAutoOn = false;
byte hatPitch = 128;
byte crashAuto[32];
boolean crashAutoOn = false;
byte crashPitch = 128;

byte currentVoice = 0; // which voice are we editing 0 = kick, 1 = snare, 2 = hat, 3 = crash

byte tickCounter = 0; // 96 ticks to a quarter = 24 ticks to a 16th
volatile byte currentStep = 0;

boolean longStep = true; // the first/longer step of a swing pair
byte swing = 0; // the swing amount from 0 to 8 ticks
byte tempSwing = 0; // we run into trouble if we update swing values at any time - we use this as a buffer variable and only change swing on tick 0

boolean showingNumbers = false; // are we busy displaying numbers
byte number = 0; // te number to display

byte mode = 0; // 0 = edit, 1 = master, 2 = trigger, 3 = live

byte bpm = 120; 

byte kickVolume = 255;
byte snareVolume = 255;
byte hatVolume = 255;
byte crashVolume = 255;

boolean shiftL = false;

unsigned long roughMillis = 0; // we want to use this as an erzats millis timer

// load & save
byte toc[16] = {
  0, 0, 0, 0,
  0, 0, 0, 0,  // 14 bytes to serve as table of contents (toc) for our 112 memory locations (stored as 14 bytes on eeprom page 448) 
  0, 0, 0, 0,  // add 2 bytes at the end for the sake of simplicity, but their values will never change from 0
  0, 0, 0, 0}; // these are the last two unused rows on the 4th triger page (trigPage = 3)

byte patchNum; // the number of the patch we want to load or save 

byte trigPage = 0; // which trigger page are we on?

unsigned long longPress = 0; // set to zero if we're not waiting

boolean repeat = false;
boolean trueStep = 0;

byte cued = 255; // the pattern that's cued to load - 255 for none
byte nowPlaying = 255; // the pattern that's currently playing - 255 for none
byte confirm = 255; // a pattern that needs to be confirmed before erasing or overwriting it
boolean save = false; //  a flag that inicated whether the confirm is for a save

unsigned long slowBlink = 0;
unsigned long fastBlink = 0;

byte triggerChannel = 16; // the channel that pattern trigger messages are sent on

byte seqRunning = true; // is the sequencer?

byte xorDistortion = 0; // the amount of XOR distortion

boolean voiceActive[4] = {true, true, true, true};

    
MIDI_CREATE_INSTANCE(HardwareSerial, Serial, midiA);


